"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.ma_bots2.lab import get_type_lab

data = [
    (" of ", "forests and woodlands of", "غابات"),
    (" of ", "ports and harbours of", "مرافئ وموانئ"),
    (" of ", " university of", "جامعة"),
    ("in", "arizona territory", "إقليم أريزونا"),
    (" by ", "basketball playerss in lebanon", "لاعبو كرة سلة في لبنان"),
    (" in ", "former buildings and structures", "مبان ومنشآت سابقة"),
    (" opened in ", "railway stations in south korea", "محطات السكك الحديدية في كوريا الجنوبية"),
    (" in ", "tunisian expatriate basketball people", "أعلام كرة سلة تونسيون مغتربون"),
    (" by ", "history of central african republic", "تاريخ جمهورية إفريقيا الوسطى"),
    (" involving ", "battles of napoleonic wars", "معارك الحروب النابليونية"),
    (" by ", "burials in washington (state)", "مدفونون في ولاية واشنطن"),
    (" by ", "taiwanese football club seasons", "مواسم أندية كرة قدم تايوانية"),
    (" closed in ", "railway stations in france", "محطات السكك الحديدية في فرنسا"),
    (" by ", "male actors from the west midlands (county)", "ممثلون ذكور من مقاطعة ميدلاند الغربية"),
    (" in ", "demolished buildings and structures", "مبان ومنشآت مهدمة"),
    (" by ", "weapons of mass destruction", "أسلحة دمار شامل"),
    (" in ", "lithuanian expatriate basketball people", "أعلام كرة سلة ليتوانيون مغتربون"),
    (" in ", "years of 21st century", "سنوات القرن 21"),
    (" in ", "by university or college", "حسب الجامعة أو الكلية"),
    (" in ", "buildings and structures under construction", "مبان ومنشآت تحت بناء"),
    (" in ", "lists of buildings and structures", "قوائم مبان ومنشآت"),
    (" in ", "years of 18th century", "سنوات القرن 18"),
    (" in ", "senegalese expatriate basketball people", "أعلام كرة سلة سنغاليون مغتربون"),
    (" in ", "sports clubs and teams", "أندية وفرق رياضية"),
    (" by ", "road incident deaths in the united states", "وفيات حوادث الطرق في الولايات المتحدة"),
    (" in ", "russian expatriate volleyball players", "لاعبو كرة طائرة روس مغتربون"),
    (" in ", "years of 17th century", "سنوات القرن 17"),
    (" in ", "port cities and towns", "مدن وبلدات ساحلية"),
    (" in ", "golf clubs and courses", "نوادي الغولف والدورات"),
    (" in ", "south korean expatriate sports-people", "رياضيون كوريون جنوبيون مغتربون"),
    (" by ", "ethnic groups in china", "مجموعات عرقية في الصين"),
    (" to ", "permanent representatives of jamaica", "مندوبو جامايكا الدائمون"),
    (" opened in ", "railway stations in japan", "محطات السكك الحديدية في اليابان"),
    (" disestablished in ", "art museums and galleries", "متاحف فنية ومعارض"),
    (" by ", "1789 in the united kingdom", "المملكة المتحدة في 1789"),
    (" opened in ", "railway stations in sweden", "محطات السكك الحديدية في السويد"),
    (" established in ", "sports clubs and teams", "أندية وفرق رياضية"),
    (" by ", "establishments in southeast asia", "تأسيسات في جنوب شرق آسيا"),
    (" opened in ", "railway stations in germany", "محطات السكك الحديدية في ألمانيا"),
    (" in ", "victims of aviation accidents or incidents", "ضحايا حوادث طيران"),
    (" in ", "years of 20th century", "سنوات القرن 20"),
    (" by ", "skyscrapers in the united arab emirates", "ناطحات سحاب في الإمارات العربية المتحدة"),
    (" to ", "ambassadors of south africa", "سفراء جنوب إفريقيا"),
    (" by ", "welsh rugby union players", "لاعبو اتحاد رجبي ويلزيون"),
    (" closed in ", "railway stations in northern-ireland", "محطات السكك الحديدية في أيرلندا الشمالية"),
    (" by ", "sports venues in australia", "ملاعب رياضية في أستراليا"),
    (" closed in ", "railway stations in albania", "محطات السكك الحديدية في ألبانيا"),
    (" in ", "swiss expatriate basketball people", "أعلام كرة سلة سويسريون مغتربون"),
    (" in ", "roman catholic church buildings", "مبان كنائس رومانية كاثوليكية"),
    (" by ", "christianity in the united states", "المسيحية في الولايات المتحدة"),
    (" in ", "transportation buildings and structures", "مبان ومنشآت نقل"),
    (" by ", "transportation buildings and structures in new hampshire", "مبان ومنشآت نقل في نيوهامشير"),
    (" by ", "1789 in men's football", "كرة القدم للرجال في 1789"),
    (" by ", "buildings and structures in idaho", "مبان ومنشآت في أيداهو"),
    (" in ", "olympic silver medalists for the united states", "فائزون بميداليات فضية أولمبية من الولايات المتحدة"),
    (" by ", "netball in north america", "كرة الشبكة في أمريكا الشمالية"),
    (" in ", "religious buildings and structures", "مبان ومنشآت دينية"),
    (" in ", "years of 19th century", "سنوات القرن 19"),
    (" closed in ", "railway stations in germany", "محطات السكك الحديدية في ألمانيا"),
    (" established in ", "military units and formations", "وحدات وتشكيلات عسكرية"),
    (" by ", "history of austria hungary", "تاريخ الإمبراطورية النمساوية المجرية"),
    (" in ", "transport buildings and structures", "مبان ومنشآت نقل"),
    (" in ", "lists of mayors of places", "قوائم رؤساء بلديات"),
    (" in ", "church of jesus christ of latter-day saints", "كنيسة يسوع المسيح لقديسي الأيام الأخيرة"),
    (" by ", "rivers of united states", "أنهار الولايات المتحدة"),
    (" by ", "history of nova scotia", "تاريخ نوفا سكوشا"),
    (" by ", "1789 establishments in india", "تأسيسات سنة 1789 في الهند"),
    (" by ", "lists of bosnia and herzegovina people", "قوائم بوسنيون"),
    (
        " from ",
        "know-nothing members of united states house-of-representatives",
        "أعضاء حزب لا أدري في مجلس النواب الأمريكي",
    ),
    (" from ", "united states house-of-representatives", "مجلس النواب الأمريكي"),
    (" by ", "trade unions in the caribbean", "نقابات عمالية في الكاريبي"),
    (" by ", "1789 in women's sport", "رياضة نسائية في 1789"),
    (" hosted by ", "international field hockey competitions", "منافسات هوكي ميدان دولية"),
    (" opened in ", "railway stations in the united states", "محطات السكك الحديدية في الولايات المتحدة"),
    (" by ", "1789 crimes in africa", "جرائم 1789 في إفريقيا"),
    (" by ", "buildings and structures in prince edward island", "مبان ومنشآت في جزيرة الأمير إدوارد"),
    (" opened in ", "railway stations in latvia", "محطات السكك الحديدية في لاتفيا"),
    (" concerning ", "united nations security council resolutions", "قرارات مجلس الأمن التابع للأمم المتحدة"),
    (" opened in ", "railway stations in indonesia", "محطات السكك الحديدية في إندونيسيا"),
    (" closed in ", "railway stations in republic-of ireland", "محطات السكك الحديدية في جمهورية أيرلندا"),
    (" to ", "ambassadors of federated states-of micronesia", "سفراء ولايات ميكرونيسيا المتحدة"),
    (" in ", "south african expatriate sports-people", "رياضيون جنوب إفريقيون مغتربون"),
    (" for ", "central american and caribbean games medalists", "فائزون بميداليات ألعاب أمريكا الوسطى والكاريبي"),
    (" in ", "years of 16th century", "سنوات القرن 16"),
    (" by ", "1789 in south american football", "كرة القدم الأمريكية الجنوبية في 1789"),
    (" in ", "united states house-of-representatives elections", "انتخابات مجلس النواب الأمريكي"),
    (" in ", "art museums and galleries", "متاحف فنية ومعارض"),
    (" opened in ", "railway stations in serbia", "محطات السكك الحديدية في صربيا"),
    (" to ", "ambassadors of united states", "سفراء الولايات المتحدة"),
    (" involving the ", "military operations of syrian civil war", "عمليات عسكرية في الحرب الأهلية السورية"),
    (" by ", "protected areas of georgia (u.s. state)", "مناطق محمية في ولاية جورجيا"),
    (" by ", "universities and colleges in andhra pradesh", "جامعات وكليات في أندرا برديش"),
    (" by ", "1789 in north america", "أمريكا الشمالية في 1789"),
    (" in ", "lists of universities and colleges", "قوائم جامعات وكليات"),
    (" based in ", "medical and health organizations", "منظمات طبية وصحية"),
    (" in ", "military units and formations", "وحدات وتشكيلات عسكرية"),
    (" completed in ", "religious buildings and structures", "مبان ومنشآت دينية"),
    (" by ", "disestablishments in georgia (u.s. state)", "انحلالات في ولاية جورجيا"),
    (" by ", "history of northern ireland", "تاريخ أيرلندا الشمالية"),
    (" in ", "parliament of united kingdom", "برلمان المملكة المتحدة"),
    (" opened in ", "railway stations in northern-ireland", "محطات السكك الحديدية في أيرلندا الشمالية"),
    (" in ", "australian rules football clubs", "أندية كرة قدم أسترالية"),
    (" by ", "1789 elections in the united states", "انتخابات 1789 في الولايات المتحدة"),
    (" by ", "buildings and structures in georgia (u.s. state)", "مبان ومنشآت في ولاية جورجيا"),
    (" by ", "lists of country subdivisions", "قوائم تقسيمات البلد"),
    (" in ", "attacks on buildings and structures", "هجمات على مبان ومنشآت"),
    (" in ", "french expatriate rugby union players", "لاعبو اتحاد رجبي فرنسيون مغتربون"),
    (" opened in ", "railway stations in austria", "محطات السكك الحديدية في النمسا"),
    (" hosted by ", "international ice hockey competitions", "منافسات هوكي جليد دولية"),
    (" opened in ", "railway stations in the netherlands", "محطات السكك الحديدية في هولندا"),
    (" from ", "players of american football", "لاعبو كرة قدم أمريكية"),
    (" in ", "defunct sports clubs and teams", "أندية وفرق رياضية سابقة"),
    (" in ", "installations of united states air force", "منشآت في القوات الجوية الأمريكية"),
    (" in ", "united states air force", "القوات الجوية الأمريكية"),
    (" in ", "christian buildings and structures", "مبان ومنشآت مسيحية"),
    (" from ", "major league baseball players", "لاعبو دوري كرة القاعدة الرئيسي"),
    (" opened in ", "railway stations in great britain", "محطات السكك الحديدية في بريطانيا العظمى"),
    (" by ", "1789 in brazilian sport", "رياضة برازيلية في 1789"),
    (" by ", "history of north america", "تاريخ أمريكا الشمالية"),
    (" by ", "people from west sumatra", "أشخاص من سومطرة الغربية"),
    (" by ", "volleyball competitions in asia", "منافسات كرة طائرة في آسيا"),
    (" by ", "anglican bishops in asia", "أساقفة أنجليكيون في آسيا"),
    (
        " by ",
        "national-register-of-historic-places in north carolina",
        "السجل الوطني للأماكن التاريخية في كارولاينا الشمالية",
    ),
    (" involving ", "battles of vietnam war", "معارك حرب فيتنام"),
    (" by ", "sports-people in västmanland county", "رياضيون في مقاطعة فستمانلاند"),
    (" for ", "olympic field hockey players", "لاعبو هوكي ميدان أولمبيون"),
    (" in ", "expatriates from northern ireland", "مغتربون من أيرلندا الشمالية"),
    (" for ", "olympic table tennis players", "لاعبو كرة طاولة أولمبيون"),
    (" by ", "port cities and towns", "مدن وبلدات ساحلية"),
    (" for ", "african games silver medalists", "فائزون بميداليات فضية في الألعاب الإفريقية"),
    (" by ", "1789 in asian sport", "رياضة آسيوية في 1789"),
    (" by ", "1789 in chinese sport", "رياضة صينية في 1789"),
    (" in ", "track and field athletes", "رياضيو المسار والميدان"),
    (" by ", "1789 in youth football", "كرة القدم للشباب في 1789"),
    (" by ", "transport infrastructure in south america", "البنية التحتية للنقل في أمريكا الجنوبية"),
    (
        " in ",
        "railway stations on the-national-register-of-historic-places",
        "محطات السكك الحديدية في السجل الوطني للأماكن التاريخية",
    ),
    (" in ", "bulgarian expatriate basketball people", "أعلام كرة سلة بلغاريون مغتربون"),
    (" established in ", "australian rules football clubs", "أندية كرة قدم أسترالية"),
    (" on ", "agricultural buildings and structures", "مبان ومنشآت زراعية"),
    (
        " in ",
        "agricultural buildings and structures on the-national-register-of-historic-places",
        "مبان ومنشآت زراعية في السجل الوطني للأماكن التاريخية",
    ),
    (" to ", "permanent representatives of kyrgyzstan", "مندوبو قيرغيزستان الدائمون"),
    (" by ", "tourism in republic-of ireland", "سياحة في جمهورية أيرلندا"),
    (" opened in ", "railway stations in hong kong", "محطات السكك الحديدية في هونغ كونغ"),
    (" opened in ", "railway stations in spain", "محطات السكك الحديدية في إسبانيا"),
    (
        " in ",
        "bank buildings on the-national-register-of-historic-places",
        "مباني بنوك في السجل الوطني للأماكن التاريخية",
    ),
    (" by ", "nations in the summer olympics", "بلدان في الألعاب الأولمبية الصيفية"),
    (" for ", "pan american games medalists", "فائزون بميداليات دورة الألعاب الأمريكية"),
    (" by ", "universities and colleges in texas", "جامعات وكليات في تكساس"),
    (" in ", "attacks on diplomatic missions", "هجمات على بعثات دبلوماسية"),
    (
        " from ",
        "whig party members of united states house-of-representatives",
        "أعضاء حزب اليمين في مجلس النواب الأمريكي",
    ),
    (
        " from ",
        "federalist party members of united states house-of-representatives",
        "أعضاء الحزب الفيدرالي الأمريكي في مجلس النواب الأمريكي",
    ),
    (" by ", "historic districts in massachusetts", "المناطق التاريخية في ماساتشوستس"),
    (" by ", "rugby union players from west yorkshire", "لاعبو اتحاد رجبي من غرب يوركشاير"),
    (" by ", "railway stations in the philippines", "محطات السكك الحديدية في الفلبين"),
    (" to ", "trinidad and tobago emigrants", "ترنيداديون مهاجرون"),
    (" by ", "unincorporated communities in alaska", "مجتمعات فردية في ألاسكا"),
    (" by ", "1789 in south america", "أمريكا الجنوبية في 1789"),
    (" by ", "parks in south america", "متنزهات في أمريكا الجنوبية"),
    (" disestablished in ", "television channels and stations", "قنوات وشبكات تلفزيونية"),
    (" to ", "permanent representatives of bahrain", "مندوبو البحرين الدائمون"),
    (" opened in ", "railway stations in bangladesh", "محطات السكك الحديدية في بنغلاديش"),
    (" established in ", "art museums and galleries", "متاحف فنية ومعارض"),
    (" opened in ", "railway stations in denmark", "محطات السكك الحديدية في الدنمارك"),
    (" by ", "united states senate candidates", "مرشحو مجلس الشيوخ الأمريكي"),
    (" in ", "spanish expatriate handball players", "لاعبو كرة يد إسبان مغتربون"),
    (" opened in ", "railway stations in poland", "محطات السكك الحديدية في بولندا"),
    (" in ", "impact of covid-19 pandemic", "تأثيرات جائحة فيروس كورونا"),
    (" opened in ", "railway stations in russia", "محطات السكك الحديدية في روسيا"),
    (" for ", "commonwealth games bronze medalists", "فائزون بميداليات برونزية في ألعاب الكومنولث"),
    (
        " in ",
        "buildings and structures on the-national-register-of-historic-places",
        "مبان ومنشآت في السجل الوطني للأماكن التاريخية",
    ),
    (" in ", "attacks on military installations", "هجمات على منشآت عسكرية"),
    (" opened in ", "railway stations in the russian empire", "محطات السكك الحديدية في الإمبراطورية الروسية"),
    (" in ", "riots and civil disorder", "شغب وعصيان مدني"),
    (" by ", "electronic dance music albums", "ألبومات موسيقى الرقص الإلكترونية"),
    (" by ", "sports governing bodies in north america", "هيئات تنظيم رياضية في أمريكا الشمالية"),
    (" by ", "women's footballers in ireland", "لاعبات كرة قدم في أيرلندا"),
    (" in ", "military and war museums", "متاحف عسكرية وحربية"),
    (" from ", "democratic party united states senators", "أعضاء مجلس الشيوخ الأمريكي من الحزب الديمقراطي"),
    (" by ", "universities and colleges in ukraine", "جامعات وكليات في أوكرانيا"),
    (" closed in ", "railway stations in new zealand", "محطات السكك الحديدية في نيوزيلندا"),
    (" for ", "african games bronze medalists", "فائزون بميداليات برونزية في الألعاب الإفريقية"),
    (" in ", "military operations of war", "عمليات عسكرية في الحرب"),
    (
        " involving ",
        "military operations of war in afghanistan (1789–1789)",
        "عمليات عسكرية في الحرب في أفغانستان (1789–1789)",
    ),
    (" by ", "field hockey playerss in germany", "لاعبو هوكي ميدان في ألمانيا"),
    (" in ", "history of petroleum industry", "تاريخ صناعة بترولية"),
    (" in ", "private universities and colleges", "جامعات وكليات خاصة"),
    (" in ", "croatian expatriate basketball people", "أعلام كرة سلة كروات مغتربون"),
    (" to ", "emigrants from the russian empire", "مهاجرون من الإمبراطورية الروسية"),
    (" by ", "railway stations in romania", "محطات السكك الحديدية في رومانيا"),
    (" by ", "female field hockey players", "لاعبات هوكي ميدان"),
    (" in ", "brazilian expatriate basketball people", "أعلام كرة سلة برازيليون مغتربون"),
    (" by ", "tanks of united states", "دبابات الولايات المتحدة"),
    (" by ", "food and drink in europe", "أطعمة ومشروبات في أوروبا"),
    (" to ", "permanent representatives of kazakhstan", "مندوبو كازاخستان الدائمون"),
    (" for ", "islamic solidarity games silver medalists", "فائزون بميداليات فضية في ألعاب التضامن الإسلامي"),
]


@pytest.mark.parametrize("preposition, category, output", data, ids=[x[1] for x in data])
@pytest.mark.fast
def test_get_type_lab_data(preposition: str, category: str, output: str) -> None:
    label, _ = get_type_lab(preposition, category)
    assert label.strip() == output.strip()



#!/usr/bin/python3
"""Integration tests for MultiDataFormatterBase and MultiDataFormatterYearAndFrom with year-based translations."""

import re

import pytest

from ArWikiCats.time_resolvers.time_to_arabic import convert_time_to_arabic, match_time_en_first
from ArWikiCats.translations_formats import FormatDataFrom, MultiDataFormatterYearAndFrom


def get_label(text: str) -> str:
    data = {
        "writers from Hong Kong": "كتاب من هونغ كونغ",
        "writers from yemen": "كتاب من اليمن",
        "writers from Crown of Aragon": "كتاب من تاج أرغون",
        "writers gg yemen": "كتاب من اليمن",
    }
    print(f"search: {text=}")
    return data.get(text, "")


@pytest.fixture
def multi_bot_v4() -> MultiDataFormatterYearAndFrom:
    formatted_data = {
        "{year1} {country1}": "{country1} في {year1}",
    }
    country_bot = FormatDataFrom(
        formatted_data=formatted_data,
        key_placeholder="{country1}",
        value_placeholder="{country1}",
        search_callback=get_label,
        match_key_callback=lambda x: x.replace("{year1}", "").strip(),
    )
    year_bot = FormatDataFrom(
        formatted_data={},
        key_placeholder="{year1}",
        value_placeholder="{year1}",
        search_callback=convert_time_to_arabic,
        match_key_callback=match_time_en_first,
    )

    # year_bot = YearFormatData(key_placeholder="{year1}", value_placeholder="{year1}")

    return MultiDataFormatterYearAndFrom(
        country_bot=country_bot,
        year_bot=year_bot,
        other_key_first=True,
    )


@pytest.mark.unit
class TestYearPart:
    test_data_standard = {
        "100s": "عقد 100",
    }

    @pytest.mark.parametrize("category,expected", test_data_standard.items(), ids=test_data_standard.keys())
    def test_year_combinations(self, multi_bot_v4: MultiDataFormatterYearAndFrom, category: str, expected: str) -> None:
        """
        Test
        """
        result = multi_bot_v4.other_bot.search_all(category)
        assert result == expected


@pytest.mark.unit
class TestMatchKeys:
    test_keys = {
        "14th-century writers from Hong Kong": ("14th-century", "writers from Hong Kong"),
        "14th-century writers from yemen": ("14th-century", "writers from yemen"),
        "14th-century writers from yemen by city": ("14th-century", "writers from yemen by city"),
    }

    @pytest.mark.parametrize("category,expected", test_keys.items(), ids=test_keys.keys())
    def test_match_key_other_bot(
        self, multi_bot_v4: MultiDataFormatterYearAndFrom, category: str, expected: tuple[str, str]
    ) -> None:
        """
        Test
        """
        year_key, _ = expected

        result = multi_bot_v4.other_bot.match_key(category)
        assert result == year_key

    @pytest.mark.parametrize("category,expected", test_keys.items(), ids=test_keys.keys())
    def test_match_key_country_bot(
        self, multi_bot_v4: MultiDataFormatterYearAndFrom, category: str, expected: tuple[str, str]
    ) -> None:
        """
        Test
        """
        _, c_key = expected
        result = multi_bot_v4.normalize_both_new(category).nat_key
        assert result == c_key


@pytest.mark.unit
class TestCountriesPart:
    test_data_standard = {
        "writers from Hong Kong": "كتاب من هونغ كونغ",
        "writers from yemen": "كتاب من اليمن",
        "writers gg yemen": "كتاب من اليمن",
    }

    @pytest.mark.parametrize("category,expected", test_data_standard.items(), ids=test_data_standard.keys())
    def test_country_combinations(
        self, multi_bot_v4: MultiDataFormatterYearAndFrom, category: str, expected: str
    ) -> None:
        """
        Test
        """
        result = multi_bot_v4.country_bot.search_all(category)
        assert result == expected


@pytest.mark.unit
class TestPart3:
    test_data_standard = {
        "14th-century writers from Hong Kong": "كتاب من هونغ كونغ في القرن 14",
        "14th-century writers from yemen": "كتاب من اليمن في القرن 14",
        "14th-century writers from yemen by city": "",
    }

    @pytest.mark.parametrize("category,expected", test_data_standard.items(), ids=test_data_standard.keys())
    def test_year_country_combinations(
        self, multi_bot_v4: MultiDataFormatterYearAndFrom, category: str, expected: str
    ) -> None:
        """
        Test
        """
        result = multi_bot_v4.create_label(category)
        assert result == expected



#!/usr/bin/python3
"""Integration tests for format_multi_data  """

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.translations_formats import (
    MultiDataFormatterBase,
    format_multi_data,
)


@pytest.fixture
def multi_bot() -> MultiDataFormatterBase:
    under_data = {
        "under-20": "تحت 20 سنة",
        "under-15": "تحت 15 سنة",
    }
    formatted_data = {
        "{en} {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم ",
        "{en} {under_en} amateur international soccer players": "لاعبو منتخب {ar} {under_ar} لكرة القدم للهواة",
        "{en} men's {under_en} international footballers": "لاعبو منتخب {ar} {under_ar} لكرة القدم للرجال",
        "national {under_en} football team": "منتخب كرة القدم {under_ar}",
        "{en} national football team managers": "مدربو منتخب {ar} لكرة القدم",
        "{en} sports templates": "قوالب {ar} الرياضية",
        "{en} amateur international soccer players": "لاعبو منتخب {ar} لكرة القدم للهواة",
        "{en} men's a' international footballers": "لاعبو منتخب {ar} لكرة القدم للرجال للمحليين",
    }
    countries_from_nat = {
        "armenia": "أرمينيا",
        "chad": "تشاد",
        "mauritania": "موريتانيا",
        "yemen": "اليمن",
    }
    return format_multi_data(
        formatted_data=formatted_data,
        data_list=under_data,
        key_placeholder="{under_en}",
        value_placeholder="{under_ar}",
        data_list2=countries_from_nat,
        key2_placeholder="{en}",
        value2_placeholder="{ar}",
        use_other_formatted_data=True,
    )


# =========================================================
#           data_compare
# =========================================================

data_compare = {
    "armenia national football team managers": "مدربو منتخب أرمينيا لكرة القدم",
    "chad sports templates": "قوالب تشاد الرياضية",
    "yemen amateur international soccer players": "لاعبو منتخب اليمن لكرة القدم للهواة",
    "yemen men's a' international footballers": "لاعبو منتخب اليمن لكرة القدم للرجال للمحليين",
    "mauritania men's under-20 international footballers": "لاعبو منتخب موريتانيا تحت 20 سنة لكرة القدم للرجال",
    "national under-15 football team": "منتخب كرة القدم تحت 15 سنة",
}


@pytest.mark.fast
def test_data_compare_one(multi_bot: MultiDataFormatterBase) -> None:
    category = "national under-15 football team"
    expected = "منتخب كرة القدم تحت 15 سنة"

    label2 = multi_bot.search_all(category)

    assert label2 == expected


@pytest.mark.parametrize("category, expected", data_compare.items(), ids=data_compare.keys())
@pytest.mark.fast
def test_data_compare_multi(multi_bot: MultiDataFormatterBase, category: str, expected: str) -> None:
    label2 = multi_bot.search_all(category)

    assert label2 == expected


# =========================================================
#           DUMP
# =========================================================


TEMPORAL_CASES = [
    ("test_data_compare", data_compare),
]


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(multi_bot: MultiDataFormatterBase, name: str, data: dict[str, str]) -> None:
    callback = multi_bot.search_all
    expected, diff_result = one_dump_test(data, callback, do_strip=False)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



import functools

from ...helps import logger
from . import (
    countries_names_and_sports,
    jobs_multi_sports_reslover,
    match_labs,
    nationalities_and_sports,
    raw_sports,
    sport_lab_nat,
)


@functools.lru_cache(maxsize=None)
def resolve_sports_main(normalized_category) -> str:
    normalized_category = normalized_category.strip().lower().replace("category:", "")

    logger.debug("--" * 20)
    logger.debug(f"<><><><><><> <<green>> Trying sports_resolvers resolvers for: {normalized_category=}")

    resolved_label = (
        # raw_sports.wrap_team_xo_normal_2025_with_ends(normalized_category) or               #
        countries_names_and_sports.resolve_countries_names_sport_with_ends(normalized_category)
        or nationalities_and_sports.resolve_nats_sport_multi_v2(normalized_category)
        or jobs_multi_sports_reslover.jobs_in_multi_sports(normalized_category)
        # or match_labs.find_teams_2025(normalized_category) or
        # or sport_lab_nat.sport_lab_nat_load_new(normalized_category)
        or ""
    )

    logger.info_if_or_debug(
        f"<<yellow>> end resolve_sports_main: {normalized_category=}, {resolved_label=}", resolved_label
    )
    return resolved_label


__all__ = [
    "resolve_sports_main",
]



#!/usr/bin/python3
"""
!
"""

import json
import sys
from pathlib import Path
from typing import Any, List, Mapping, Union

from humanize import naturalsize

from ..config import app_settings
from ..helps.log import logger

all_len = {}


def format_size(key: str, value: int | float, lens: List[Union[str, Any]]) -> str:
    """Format byte sizes unless the key should remain numeric."""
    if key in lens:
        return value
    return naturalsize(value, binary=True)


def save_data(bot: str, tab: Mapping) -> None:
    """Persist bot data to JSON files when a save path is configured."""
    if not app_settings.save_data_path:
        return

    bot_path = Path(app_settings.save_data_path) / bot
    try:
        bot_path.mkdir(parents=True, exist_ok=True)

        for name, data in tab.items():
            if not data:
                continue
            if isinstance(data, dict) or isinstance(data, list):
                # sort data by key
                if isinstance(data, dict):
                    data = dict(sorted(data.items(), key=lambda item: item[0].lower()))
                elif isinstance(data, list):
                    data = sorted(set(data))
                with open(bot_path / f"{name}.json", "w", encoding="utf-8") as f:
                    json.dump(data, f, ensure_ascii=False, indent=4)
    except Exception as e:
        logger.error(f"Error saving data to {bot_path}: {e}", exc_info=True)


def data_len(
    bot: str,
    tab: Mapping[str, int | float],
) -> None:
    """Collect and optionally save size statistics for the given bot data."""
    data = {
        x: {
            "count": len(v) if not isinstance(v, int) else v,
            "size": format_size(x, sys.getsizeof(v), {}),
        }
        for x, v in tab.items()
    }
    if app_settings.save_data_path:
        save_data(bot, tab)

    if not data:
        return

    all_len.setdefault(bot, {})
    all_len[bot].update(data)


def dump_all_len() -> dict[str, dict]:
    """Return aggregated counts and sizes for all processed bots."""
    # sort all_len by keys ignore case
    all_len_save = {
        "by_count": {},
        "all": dict(sorted(all_len.items(), key=lambda item: item[0].lower())),
    }
    for _, v in all_len.items():
        for var, tab in v.items():
            all_len_save["by_count"].setdefault(var, tab["count"])

    sorted_items = sorted(all_len_save["by_count"].items(), key=lambda item: item[1], reverse=True)
    all_len_save["by_count"] = {k: f"{v:,}" for k, v in sorted_items}

    return all_len_save



"""
This module provides functionality to translate category titles
that follow a nationality pattern. It uses a pre-configured
bot to handle the translation logic.

"""

import functools
import re

from ..helps import dump_data, logger
from ..translations import RELIGIOUS_KEYS_PP, All_Nat, all_country_with_nat, countries_en_as_nationality_keys
from ..translations_formats import FormatDataV2
from .categories_patterns.NAT_males import NAT_DATA_MALES

countries_en_keys = [x.get("en") for x in all_country_with_nat.values() if x.get("en")]


def fix_keys(category: str) -> str:
    category = category.replace("category:", "").replace("'", "").lower()
    category = re.sub(r"\bthe\b", "", category)
    category = re.sub(r"\s+", " ", category)

    replacements = {
        "expatriates": "expatriate",
    }

    for old, new in replacements.items():
        category = category.replace(old, new)

    return category.strip()


@functools.lru_cache(maxsize=1)
def _bot_new() -> FormatDataV2:
    formatted_data = dict(NAT_DATA_MALES)
    formatted_data = {fix_keys(k): v for k, v in formatted_data.items()}
    formatted_data.update(
        {
            "{en_nat} diaspora": "شتات {male}",
        }
    )

    nats_data = {
        x: {
            "males": v["males"],
            "male": v["male"],
            "females": v["females"],
        }
        for x, v in All_Nat.items()
        if v.get("males")
    }
    nats_data.update(
        {
            x: {
                "males": v["males"],
                "females": v["females"],
            }
            for x, v in RELIGIOUS_KEYS_PP.items()
        }
    )

    return FormatDataV2(
        formatted_data=formatted_data,
        data_list=nats_data,
        key_placeholder="{en_nat}",
        text_after=" people",
        text_before="the ",
    )


@functools.lru_cache(maxsize=10000)
# @dump_data(1)
def resolve_nat_men_pattern_new(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_nat_men_pattern_new: {category=}")

    normalized_category = fix_keys(category)

    if normalized_category in countries_en_as_nationality_keys or normalized_category in countries_en_keys:
        logger.info(f"<<yellow>> skip mens_resolver_labels: {category=}, [result=]")
        return ""

    yc_bot = _bot_new()
    result = yc_bot.create_label(normalized_category)

    if result and category.lower().startswith("category:"):
        result = "تصنيف:" + result

    logger.info_if_or_debug(f"<<yellow>> end resolve_nat_men_pattern_new: {category=}, {result=}", result)

    return result or ""


__all__ = [
    "resolve_nat_men_pattern_new",
]



import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

test_same = {
    "angola–seychelles relations": "العلاقات الأنغولية السيشلية",
    "australia–seychelles relations": "العلاقات الأسترالية السيشلية",
    "bangladesh–seychelles relations": "العلاقات البنغلاديشية السيشلية",
    "belgium–seychelles relations": "العلاقات البلجيكية السيشلية",
    "burundi–seychelles relations": "العلاقات البوروندية السيشلية",
    "canada–seychelles relations": "العلاقات السيشلية الكندية",
    "china–seychelles relations": "العلاقات السيشلية الصينية",
    "cuba–seychelles relations": "العلاقات السيشلية الكوبية",
    "ethiopia–seychelles relations": "العلاقات الإثيوبية السيشلية",
    "france–seychelles relations": "العلاقات السيشلية الفرنسية",
    "germany–seychelles relations": "العلاقات الألمانية السيشلية",
    "ghana–seychelles relations": "العلاقات السيشلية الغانية",
    "india–seychelles relations": "العلاقات السيشلية الهندية",
    "israel–seychelles relations": "العلاقات الإسرائيلية السيشلية",
    "italy–seychelles relations": "العلاقات الإيطالية السيشلية",
    "japan–seychelles relations": "العلاقات السيشلية اليابانية",
    "kenya–seychelles relations": "العلاقات السيشلية الكينية",
    "lesotho–seychelles relations": "العلاقات السيشلية الليسوتية",
    "luxembourg–seychelles relations": "العلاقات السيشلية اللوكسمبورغية",
    "madagascar–seychelles relations": "العلاقات السيشلية المدغشقرية",
    "malaysia–seychelles relations": "العلاقات السيشلية الماليزية",
    "mauritius–seychelles relations": "العلاقات السيشلية الموريشيوسية",
    "norway–seychelles relations": "العلاقات السيشلية النرويجية",
    "pakistan–seychelles relations": "العلاقات الباكستانية السيشلية",
    "palestine–seychelles relations": "العلاقات السيشلية الفلسطينية",
    "poland–seychelles relations": "العلاقات البولندية السيشلية",
    "russia–seychelles relations": "العلاقات الروسية السيشلية",
    "seychelles–south korea relations": "العلاقات السيشلية الكورية الجنوبية",
    "seychelles–sri lanka relations": "العلاقات السريلانكية السيشلية",
    "seychelles–sweden relations": "العلاقات السويدية السيشلية",
    "seychelles–tanzania relations": "العلاقات التنزانية السيشلية",
    "seychelles–uganda relations": "العلاقات الأوغندية السيشلية",
    "seychelles–united kingdom relations": "العلاقات البريطانية السيشلية",
    "seychelles–united states relations": "العلاقات الأمريكية السيشلية",
    "seychelles–yemen relations": "العلاقات السيشلية اليمنية",
    "antigua and barbuda–saint vincent and grenadines relations": "علاقات أنتيغوا وباربودا وسانت فنسنت وجزر غرينادين",
    "barbados–saint vincent and grenadines relations": "علاقات بربادوس وسانت فنسنت وجزر غرينادين",
    "belize–saint vincent and grenadines relations": "علاقات بليز وسانت فنسنت وجزر غرينادين",
    "canada–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وكندا",
    "chile–saint vincent and grenadines relations": "علاقات تشيلي وسانت فنسنت وجزر غرينادين",
    "china–saint vincent and grenadines relations": "علاقات الصين وسانت فنسنت وجزر غرينادين",
    "czech republic–saint vincent and grenadines relations": "علاقات التشيك وسانت فنسنت وجزر غرينادين",
    "dominica–saint vincent and grenadines relations": "علاقات دومينيكا وسانت فنسنت وجزر غرينادين",
    "finland–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وفنلندا",
    "france–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وفرنسا",
    "germany–saint vincent and grenadines relations": "علاقات ألمانيا وسانت فنسنت وجزر غرينادين",
    "ghana–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وغانا",
    "grenada–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وغرينادا",
    "india–saint vincent and grenadines relations": "علاقات الهند وسانت فنسنت وجزر غرينادين",
    "ireland–saint vincent and grenadines relations": "علاقات أيرلندا وسانت فنسنت وجزر غرينادين",
    "italy–saint vincent and grenadines relations": "علاقات إيطاليا وسانت فنسنت وجزر غرينادين",
    "jamaica–saint vincent and grenadines relations": "علاقات جامايكا وسانت فنسنت وجزر غرينادين",
    "japan–saint vincent and grenadines relations": "علاقات اليابان وسانت فنسنت وجزر غرينادين",
    "malaysia–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وماليزيا",
    "netherlands–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وهولندا",
    "new zealand–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين ونيوزيلندا",
    "philippines–saint vincent and grenadines relations": "علاقات الفلبين وسانت فنسنت وجزر غرينادين",
    "poland–saint vincent and grenadines relations": "علاقات بولندا وسانت فنسنت وجزر غرينادين",
    "portugal–saint vincent and grenadines relations": "علاقات البرتغال وسانت فنسنت وجزر غرينادين",
    "saint kitts and nevis–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وسانت كيتس ونيفيس",
    "saint lucia–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وسانت لوسيا",
    "saint vincent and grenadines–spain relations": "علاقات إسبانيا وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–switzerland relations": "علاقات سانت فنسنت وجزر غرينادين وسويسرا",
    "saint vincent and grenadines–taiwan relations": "علاقات تايوان وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–trinidad and tobago relations": "علاقات ترينيداد وتوباغو وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–tunisia relations": "علاقات تونس وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–turkey relations": "علاقات تركيا وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–united kingdom relations": "علاقات المملكة المتحدة وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–united states relations": "علاقات الولايات المتحدة وسانت فنسنت وجزر غرينادين",
    "angola–são tomé and príncipe relations": "علاقات أنغولا وساو تومي وبرينسيب",
    "argentina–são tomé and príncipe relations": "علاقات الأرجنتين وساو تومي وبرينسيب",
    "australia–são tomé and príncipe relations": "علاقات أستراليا وساو تومي وبرينسيب",
    "belgium–são tomé and príncipe relations": "علاقات بلجيكا وساو تومي وبرينسيب",
    "brazil–são tomé and príncipe relations": "علاقات البرازيل وساو تومي وبرينسيب",
    "canada–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وكندا",
    "cape verde–são tomé and príncipe relations": "علاقات الرأس الأخضر وساو تومي وبرينسيب",
    "china–são tomé and príncipe relations": "علاقات الصين وساو تومي وبرينسيب",
    "colombia–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وكولومبيا",
    "cyprus–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وقبرص",
    "equatorial guinea–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وغينيا الاستوائية",
    "finland–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وفنلندا",
    "france–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وفرنسا",
    "gabon–são tomé and príncipe relations": "علاقات الغابون وساو تومي وبرينسيب",
    "germany–são tomé and príncipe relations": "علاقات ألمانيا وساو تومي وبرينسيب",
    "india–são tomé and príncipe relations": "علاقات الهند وساو تومي وبرينسيب",
    "indonesia–são tomé and príncipe relations": "علاقات إندونيسيا وساو تومي وبرينسيب",
    "iran–são tomé and príncipe relations": "علاقات إيران وساو تومي وبرينسيب",
    "italy–são tomé and príncipe relations": "علاقات إيطاليا وساو تومي وبرينسيب",
    "lithuania–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وليتوانيا",
    "mexico–são tomé and príncipe relations": "علاقات المكسيك وساو تومي وبرينسيب",
    "mozambique–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وموزمبيق",
    "nigeria–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب ونيجيريا",
    "norway–são tomé and príncipe relations": "علاقات النرويج وساو تومي وبرينسيب",
    "paraguay–são tomé and príncipe relations": "علاقات باراغواي وساو تومي وبرينسيب",
    "portugal–são tomé and príncipe relations": "علاقات البرتغال وساو تومي وبرينسيب",
    "russia–são tomé and príncipe relations": "علاقات روسيا وساو تومي وبرينسيب",
    "são tomé and príncipe–european union relations": "علاقات الاتحاد الأوروبي وساو تومي وبرينسيب",
    "são tomé and príncipe–serbia relations": "علاقات ساو تومي وبرينسيب وصربيا",
    "são tomé and príncipe–spain relations": "علاقات إسبانيا وساو تومي وبرينسيب",
    "são tomé and príncipe–sweden relations": "علاقات السويد وساو تومي وبرينسيب",
    "são tomé and príncipe–taiwan relations": "علاقات تايوان وساو تومي وبرينسيب",
    "são tomé and príncipe–united kingdom relations": "علاقات المملكة المتحدة وساو تومي وبرينسيب",
    "são tomé and príncipe–united states relations": "علاقات الولايات المتحدة وساو تومي وبرينسيب",
    "australia–serbia-and-montenegro relations": "علاقات أستراليا وصربيا والجبل الأسود",
    "bosnia and herzegovina–serbia-and-montenegro relations": "علاقات البوسنة والهرسك وصربيا والجبل الأسود",
    "bulgaria–serbia-and-montenegro relations": "علاقات بلغاريا وصربيا والجبل الأسود",
    "canada–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وكندا",
    "cyprus–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وقبرص",
    "czech republic–serbia-and-montenegro relations": "علاقات التشيك وصربيا والجبل الأسود",
    "egypt–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود ومصر",
    "el salvador–serbia-and-montenegro relations": "علاقات السلفادور وصربيا والجبل الأسود",
    "iceland–serbia-and-montenegro relations": "علاقات آيسلندا وصربيا والجبل الأسود",
    "jordan–serbia-and-montenegro relations": "علاقات الأردن وصربيا والجبل الأسود",
    "kazakhstan–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وكازاخستان",
    "kuwait–serbia-and-montenegro relations": "علاقات الكويت وصربيا والجبل الأسود",
    "lithuania–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وليتوانيا",
    "malaysia–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وماليزيا",
    "myanmar–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وميانمار",
    "north macedonia–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود ومقدونيا الشمالية",
    "norway–serbia-and-montenegro relations": "علاقات النرويج وصربيا والجبل الأسود",
    "oman–serbia-and-montenegro relations": "علاقات سلطنة عمان وصربيا والجبل الأسود",
    "portugal–serbia-and-montenegro relations": "علاقات البرتغال وصربيا والجبل الأسود",
    "russia–serbia-and-montenegro relations": "علاقات روسيا وصربيا والجبل الأسود",
    "rwanda–serbia-and-montenegro relations": "علاقات رواندا وصربيا والجبل الأسود",
    "serbia-and-montenegro–singapore relations": "علاقات سنغافورة وصربيا والجبل الأسود",
    "serbia-and-montenegro–slovakia relations": "علاقات سلوفاكيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–south africa relations": "علاقات جنوب إفريقيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–spain relations": "علاقات إسبانيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–sudan relations": "علاقات السودان وصربيا والجبل الأسود",
    "serbia-and-montenegro–tunisia relations": "علاقات تونس وصربيا والجبل الأسود",
    "serbia-and-montenegro–ukraine relations": "علاقات أوكرانيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–united states relations": "علاقات الولايات المتحدة وصربيا والجبل الأسود",
    "serbia-and-montenegro–venezuela relations": "علاقات صربيا والجبل الأسود وفنزويلا",
    "serbia-and-montenegro–yemen relations": "علاقات اليمن وصربيا والجبل الأسود",
    "peru–serbia-and-montenegro relations": "علاقات بيرو وصربيا والجبل الأسود",
    "bahrain–serbia-and-montenegro relations": "علاقات البحرين وصربيا والجبل الأسود",
    "denmark-gambia relations": "العلاقات الدنماركية الغامبية",
    "estonia-gambia relations": "العلاقات الإستونية الغامبية",
    "ethiopia-gambia relations": "العلاقات الإثيوبية الغامبية",
    "finland-gambia relations": "العلاقات الغامبية الفنلندية",
    "france-gambia relations": "العلاقات الغامبية الفرنسية",
    "gabon-gambia relations": "العلاقات الغابونية الغامبية",
    "guinea-gambia relations": "العلاقات الغامبية الغينية",
    "cameroon-gambia relations": "العلاقات الغامبية الكاميرونية",
    "canada-gambia relations": "العلاقات الغامبية الكندية",
    "china-gambia relations": "العلاقات الصينية الغامبية",
    "colombia-gambia relations": "العلاقات الغامبية الكولومبية",
    "cuba-gambia relations": "العلاقات الغامبية الكوبية",
    "cyprus-gambia relations": "العلاقات الغامبية القبرصية",
    "czech republic-gambia relations": "العلاقات التشيكية الغامبية",
    "australia-gambia relations": "العلاقات الأسترالية الغامبية",
    "austria-gambia relations": "العلاقات الغامبية النمساوية",
    "azerbaijan-gambia relations": "العلاقات الأذربيجانية الغامبية",
    "bangladesh-gambia relations": "العلاقات البنغلاديشية الغامبية",
    "belgium-gambia relations": "العلاقات البلجيكية الغامبية",
    "botswana-gambia relations": "العلاقات البوتسوانية الغامبية",
    "brazil-gambia relations": "العلاقات البرازيلية الغامبية",
    "bulgaria-gambia relations": "العلاقات البلغارية الغامبية",
    "burkina faso-gambia relations": "العلاقات البوركينابية الغامبية",
    "Democratic republic of congo-Norway relations": "العلاقات الكونغوية الديمقراطية النرويجية",
    "Albania-Democratic republic of congo relations": "العلاقات الألبانية الكونغوية الديمقراطية",
    "Algeria-Democratic republic of congo relations": "العلاقات الجزائرية الكونغوية الديمقراطية",
    "Angola-Democratic republic of congo border": "الحدود الأنغولية الكونغوية الديمقراطية",
    "Angola-Democratic republic of congo relations": "العلاقات الأنغولية الكونغوية الديمقراطية",
    "Angola-republic of congo border": "الحدود الأنغولية الكونغوية",
    "Argentina-Democratic republic of congo relations": "العلاقات الأرجنتينية الكونغوية الديمقراطية",
    "Australia-Democratic republic of congo relations": "العلاقات الأسترالية الكونغوية الديمقراطية",
    "Austria-Democratic republic of congo relations": "العلاقات الكونغوية الديمقراطية النمساوية",
    "Azerbaijan-Democratic republic of congo relations": "العلاقات الأذربيجانية الكونغوية الديمقراطية",
    "Bahrain-Democratic republic of congo relations": "العلاقات البحرينية الكونغوية الديمقراطية",
    "Bulgaria-Democratic republic of congo relations": "العلاقات البلغارية الكونغوية الديمقراطية",
    "Burkina Faso-Democratic republic of congo relations": "العلاقات البوركينابية الكونغوية الديمقراطية",
    "Burundi-Democratic republic of congo border": "الحدود البوروندية الكونغوية الديمقراطية",
    "Burundi-Democratic republic of congo relations": "العلاقات البوروندية الكونغوية الديمقراطية",
    "Canada-Democratic republic of congo relations": "العلاقات الكندية الكونغوية الديمقراطية",
    "Cape Verde-Democratic republic of congo relations": "العلاقات الرأس الأخضرية الكونغوية الديمقراطية",
    "Central African Republic-Democratic republic of congo relations": "العلاقات الإفريقية الأوسطية الكونغوية الديمقراطية",
    "Chad-Democratic republic of congo relations": "العلاقات التشادية الكونغوية الديمقراطية",
    "China-Democratic republic of congo relations": "العلاقات الصينية الكونغوية الديمقراطية",
    "Croatia-Democratic republic of congo relations": "العلاقات الكرواتية الكونغوية الديمقراطية",
    "Cyprus-Democratic republic of congo relations": "العلاقات القبرصية الكونغوية الديمقراطية",
    "Czech Republic-Democratic republic of congo relations": "العلاقات التشيكية الكونغوية الديمقراطية",
    "Democratic republic of congo-republic of congo border": "الحدود الكونغوية الكونغوية الديمقراطية",
    "Gabon-republic of congo relations": "العلاقات الغابونية الكونغوية",
    "Iran-republic of congo relations": "العلاقات الإيرانية الكونغوية",
    "Malta-republic of congo relations": "العلاقات الكونغوية المالطية",
    "Netherlands-republic of congo relations": "العلاقات الكونغوية الهولندية",
    "Democratic republic of congo-Libya relations": "العلاقات الكونغوية الديمقراطية الليبية",
    "Democratic republic of congo-Netherlands relations": "العلاقات الكونغوية الديمقراطية الهولندية",
    "algeria–eswatini relations": "علاقات إسواتيني والجزائر",
    "angola–eswatini relations": "علاقات أنغولا وإسواتيني",
    "antigua and barbuda–dominica relations": "علاقات أنتيغوا وباربودا ودومينيكا",
    "antigua and barbuda–saint kitts and nevis relations": "علاقات أنتيغوا وباربودا وسانت كيتس ونيفيس",
    "antigua and barbuda–saint lucia relations": "علاقات أنتيغوا وباربودا وسانت لوسيا",
    "australia–eswatini relations": "علاقات أستراليا وإسواتيني",
    "austrian empire–denmark relations": "علاقات الإمبراطورية النمساوية والدنمارك",
    "austrian empire–france relations": "علاقات الإمبراطورية النمساوية وفرنسا",
    "austrian empire–prussia relations": "علاقات الإمبراطورية النمساوية وبروسيا",
    "austrian empire–russia relations": "علاقات الإمبراطورية النمساوية وروسيا",
    "austria–eswatini relations": "علاقات إسواتيني والنمسا",
    "austria–saint kitts and nevis relations": "علاقات النمسا وسانت كيتس ونيفيس",
    "austria–saint lucia relations": "علاقات النمسا وسانت لوسيا",
    "bangladesh–eswatini relations": "علاقات إسواتيني وبنغلاديش",
    "barbados–dominica relations": "علاقات بربادوس ودومينيكا",
    "barbados–saint kitts and nevis relations": "علاقات بربادوس وسانت كيتس ونيفيس",
    "barbados–saint lucia relations": "علاقات بربادوس وسانت لوسيا",
    "belgium–dominica relations": "علاقات بلجيكا ودومينيكا",
    "belgium–eswatini relations": "علاقات إسواتيني وبلجيكا",
    "belize–dominica relations": "علاقات بليز ودومينيكا",
    "benin–eswatini relations": "علاقات إسواتيني وبنين",
    "bolivia–dominica relations": "علاقات بوليفيا ودومينيكا",
    "botswana–eswatini relations": "علاقات إسواتيني وبوتسوانا",
    "brazil–saint kitts and nevis relations": "علاقات البرازيل وسانت كيتس ونيفيس",
    "bulgaria–saint lucia relations": "علاقات بلغاريا وسانت لوسيا",
    "canada–dominica relations": "علاقات دومينيكا وكندا",
    "canada–eswatini relations": "علاقات إسواتيني وكندا",
    "canada–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكندا",
    "canada–saint lucia relations": "علاقات سانت لوسيا وكندا",
    "china–dominica relations": "علاقات الصين ودومينيكا",
    "china–eswatini relations": "علاقات إسواتيني والصين",
    "china–saint kitts and nevis relations": "علاقات الصين وسانت كيتس ونيفيس",
    "china–saint lucia relations": "علاقات الصين وسانت لوسيا",
    "costa rica–saint lucia relations": "علاقات سانت لوسيا وكوستاريكا",
    "cuba–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكوبا",
    "cyprus–saint lucia relations": "علاقات سانت لوسيا وقبرص",
    "denmark–saint kitts and nevis relations": "علاقات الدنمارك وسانت كيتس ونيفيس",
    "denmark–saint lucia relations": "علاقات الدنمارك وسانت لوسيا",
    "dominica–egypt relations": "علاقات دومينيكا ومصر",
    "dominica–european union relations": "علاقات الاتحاد الأوروبي ودومينيكا",
    "dominica–france relations": "علاقات دومينيكا وفرنسا",
    "dominica–germany relations": "علاقات ألمانيا ودومينيكا",
    "dominica–greece relations": "علاقات اليونان ودومينيكا",
    "dominica–grenada relations": "علاقات دومينيكا وغرينادا",
    "dominica–guinea relations": "علاقات دومينيكا وغينيا",
    "dominica–guyana relations": "علاقات دومينيكا وغيانا",
    "dominica–haiti relations": "علاقات دومينيكا وهايتي",
    "dominica–india relations": "علاقات الهند ودومينيكا",
    "dominica–iran relations": "علاقات إيران ودومينيكا",
    "dominica–italy relations": "علاقات إيطاليا ودومينيكا",
    "dominica–jamaica relations": "علاقات جامايكا ودومينيكا",
    "dominica–japan relations": "علاقات اليابان ودومينيكا",
    "dominica–malta relations": "علاقات دومينيكا ومالطا",
    "dominica–netherlands relations": "علاقات دومينيكا وهولندا",
    "dominica–saint kitts and nevis relations": "علاقات دومينيكا وسانت كيتس ونيفيس",
    "dominica–saint lucia relations": "علاقات دومينيكا وسانت لوسيا",
    "dominica–switzerland relations": "علاقات دومينيكا وسويسرا",
    "dominica–trinidad and tobago relations": "علاقات ترينيداد وتوباغو ودومينيكا",
    "dominica–united kingdom relations": "علاقات المملكة المتحدة ودومينيكا",
    "dominica–united states relations": "علاقات الولايات المتحدة ودومينيكا",
    "dominica–venezuela relations": "علاقات دومينيكا وفنزويلا",
    "el salvador–saint kitts and nevis relations": "علاقات السلفادور وسانت كيتس ونيفيس",
    "eswatini–european union relations": "علاقات إسواتيني والاتحاد الأوروبي",
    "eswatini–finland relations": "علاقات إسواتيني وفنلندا",
    "eswatini–france relations": "علاقات إسواتيني وفرنسا",
    "eswatini–germany relations": "علاقات ألمانيا وإسواتيني",
    "eswatini–ghana relations": "علاقات إسواتيني وغانا",
    "eswatini–india relations": "علاقات إسواتيني والهند",
    "eswatini–ireland relations": "علاقات أيرلندا وإسواتيني",
    "eswatini–israel relations": "علاقات إسرائيل وإسواتيني",
    "eswatini–lesotho relations": "علاقات إسواتيني وليسوتو",
    "eswatini–malawi relations": "علاقات إسواتيني وملاوي",
    "eswatini–morocco relations": "علاقات إسواتيني والمغرب",
    "eswatini–mozambique relations": "علاقات إسواتيني وموزمبيق",
    "eswatini–netherlands relations": "علاقات إسواتيني وهولندا",
    "eswatini–nigeria relations": "علاقات إسواتيني ونيجيريا",
    "eswatini–norway relations": "علاقات إسواتيني والنرويج",
    "eswatini–pakistan relations": "علاقات إسواتيني وباكستان",
    "eswatini–russia relations": "علاقات إسواتيني وروسيا",
    "eswatini–singapore relations": "علاقات إسواتيني وسنغافورة",
    "eswatini–south africa relations": "علاقات إسواتيني وجنوب إفريقيا",
    "eswatini–south korea relations": "علاقات إسواتيني وكوريا الجنوبية",
    "eswatini–sweden relations": "علاقات إسواتيني والسويد",
    "eswatini–switzerland relations": "علاقات إسواتيني وسويسرا",
    "eswatini–taiwan relations": "علاقات إسواتيني وتايوان",
    "eswatini–thailand relations": "علاقات إسواتيني وتايلاند",
    "eswatini–united kingdom relations": "علاقات إسواتيني والمملكة المتحدة",
    "eswatini–united states relations": "علاقات إسواتيني والولايات المتحدة",
    "eswatini–yugoslavia relations": "علاقات إسواتيني ويوغسلافيا",
    "eswatini–zimbabwe relations": "علاقات إسواتيني وزيمبابوي",
    "finland–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وفنلندا",
    "finland–saint lucia relations": "علاقات سانت لوسيا وفنلندا",
    "france–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وفرنسا",
    "france–saint lucia relations": "علاقات سانت لوسيا وفرنسا",
    "germany–saint lucia relations": "علاقات ألمانيا وسانت لوسيا",
    "ghana–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وغانا",
    "greece–saint kitts and nevis relations": "علاقات اليونان وسانت كيتس ونيفيس",
    "grenada–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وغرينادا",
    "grenada–saint lucia relations": "علاقات سانت لوسيا وغرينادا",
    "guatemala–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وغواتيمالا",
    "guyana–saint lucia relations": "علاقات سانت لوسيا وغيانا",
    "honduras–saint lucia relations": "علاقات سانت لوسيا وهندوراس",
    "india–saint kitts and nevis relations": "علاقات الهند وسانت كيتس ونيفيس",
    "india–saint lucia relations": "علاقات الهند وسانت لوسيا",
    "indonesia–saint kitts and nevis relations": "علاقات إندونيسيا وسانت كيتس ونيفيس",
    "ireland–saint lucia relations": "علاقات أيرلندا وسانت لوسيا",
    "israel–saint lucia relations": "علاقات إسرائيل وسانت لوسيا",
    "italy–saint lucia relations": "علاقات إيطاليا وسانت لوسيا",
    "jamaica–saint kitts and nevis relations": "علاقات جامايكا وسانت كيتس ونيفيس",
    "jamaica–saint lucia relations": "علاقات جامايكا وسانت لوسيا",
    "japan–saint kitts and nevis relations": "علاقات اليابان وسانت كيتس ونيفيس",
    "japan–saint lucia relations": "علاقات اليابان وسانت لوسيا",
    "kenya–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكينيا",
    "malaysia–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وماليزيا",
    "mexico–saint kitts and nevis relations": "علاقات المكسيك وسانت كيتس ونيفيس",
    "netherlands–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وهولندا",
    "pakistan–saint kitts and nevis relations": "علاقات باكستان وسانت كيتس ونيفيس",
    "philippines–saint kitts and nevis relations": "علاقات الفلبين وسانت كيتس ونيفيس",
    "portugal–saint lucia relations": "علاقات البرتغال وسانت لوسيا",
    "russia–saint kitts and nevis relations": "علاقات روسيا وسانت كيتس ونيفيس",
    "saint kitts and nevis–saint lucia relations": "علاقات سانت كيتس ونيفيس وسانت لوسيا",
    "saint kitts and nevis–south africa relations": "علاقات جنوب إفريقيا وسانت كيتس ونيفيس",
    "saint kitts and nevis–suriname relations": "علاقات سانت كيتس ونيفيس وسورينام",
    "saint kitts and nevis–sweden relations": "علاقات السويد وسانت كيتس ونيفيس",
    "saint kitts and nevis–taiwan relations": "علاقات تايوان وسانت كيتس ونيفيس",
    "saint kitts and nevis–trinidad and tobago relations": "علاقات ترينيداد وتوباغو وسانت كيتس ونيفيس",
    "saint kitts and nevis–united kingdom relations": "علاقات المملكة المتحدة وسانت كيتس ونيفيس",
    "saint kitts and nevis–united states relations": "علاقات الولايات المتحدة وسانت كيتس ونيفيس",
    "saint lucia–taiwan relations": "علاقات تايوان وسانت لوسيا",
    "saint lucia–trinidad and tobago relations": "علاقات ترينيداد وتوباغو وسانت لوسيا",
    "saint lucia–united kingdom relations": "علاقات المملكة المتحدة وسانت لوسيا",
    "saint lucia–united states relations": "علاقات الولايات المتحدة وسانت لوسيا",
    "algeria–vanuatu relations": "العلاقات الجزائرية الفانواتية",
    "australia–vanuatu relations": "العلاقات الأسترالية الفانواتية",
    "austria–vanuatu relations": "العلاقات الفانواتية النمساوية",
    "bangladesh–vanuatu relations": "العلاقات البنغلاديشية الفانواتية",
    "canada–vanuatu relations": "العلاقات الفانواتية الكندية",
    "china–vanuatu relations": "العلاقات الصينية الفانواتية",
    "czech republic–vanuatu relations": "العلاقات التشيكية الفانواتية",
    "federated states-of micronesia–vanuatu relations": "العلاقات الفانواتية الميكرونيزية",
    "fiji–vanuatu relations": "العلاقات الفانواتية الفيجية",
    "france–vanuatu relations": "العلاقات الفانواتية الفرنسية",
    "gambia–vanuatu relations": "العلاقات الغامبية الفانواتية",
    "ghana–vanuatu relations": "العلاقات الغانية الفانواتية",
    "hungary–vanuatu relations": "العلاقات الفانواتية المجرية",
    "india–vanuatu relations": "العلاقات الفانواتية الهندية",
    "indonesia–vanuatu relations": "العلاقات الإندونيسية الفانواتية",
    "italy–vanuatu relations": "العلاقات الإيطالية الفانواتية",
    "japan–vanuatu relations": "العلاقات الفانواتية اليابانية",
    "morocco–vanuatu relations": "العلاقات الفانواتية المغربية",
    "new zealand–vanuatu relations": "العلاقات الفانواتية النيوزيلندية",
    "palestine–vanuatu relations": "العلاقات الفانواتية الفلسطينية",
    "papua new guinea–vanuatu relations": "العلاقات الغينية الفانواتية",
    "philippines–vanuatu relations": "العلاقات الفانواتية الفلبينية",
    "romania–vanuatu relations": "العلاقات الرومانية الفانواتية",
    "russia–vanuatu relations": "العلاقات الروسية الفانواتية",
    "spain–vanuatu relations": "العلاقات الإسبانية الفانواتية",
    "sri lanka–vanuatu relations": "العلاقات السريلانكية الفانواتية",
    "suriname–vanuatu relations": "العلاقات السورينامية الفانواتية",
    "sweden–vanuatu relations": "العلاقات السويدية الفانواتية",
    "switzerland–vanuatu relations": "العلاقات السويسرية الفانواتية",
    "tonga–vanuatu relations": "العلاقات التونغانية الفانواتية",
    "tunisia–vanuatu relations": "العلاقات التونسية الفانواتية",
    "united kingdom–vanuatu relations": "العلاقات البريطانية الفانواتية",
    "united states–vanuatu relations": "العلاقات الأمريكية الفانواتية",
    "uruguay–vanuatu relations": "العلاقات الأوروغويانية الفانواتية",
    "vanuatu–vietnam relations": "العلاقات الفانواتية الفيتنامية",
    "australia–nauru relations": "العلاقات الأسترالية الناورونية",
    "canada–nauru relations": "العلاقات الكندية الناورونية",
    "china–nauru relations": "العلاقات الصينية الناورونية",
    "cuba–nauru relations": "العلاقات الكوبية الناورونية",
    "federated states-of micronesia–nauru relations": "العلاقات الميكرونيزية الناورونية",
    "fiji–nauru relations": "العلاقات الفيجية الناورونية",
    "france–nauru relations": "العلاقات الفرنسية الناورونية",
    "germany–nauru relations": "العلاقات الألمانية الناورونية",
    "india–nauru relations": "العلاقات الناورونية الهندية",
    "iraq–nauru relations": "العلاقات العراقية الناورونية",
    "israel–nauru relations": "العلاقات الإسرائيلية الناورونية",
    "japan–nauru relations": "العلاقات الناورونية اليابانية",
    "kiribati–nauru relations": "العلاقات الكيريباتية الناورونية",
    "malaysia–nauru relations": "العلاقات الماليزية الناورونية",
    "nauru–new zealand relations": "العلاقات الناورونية النيوزيلندية",
    "nauru–philippines relations": "العلاقات الفلبينية الناورونية",
    "nauru–poland relations": "العلاقات البولندية الناورونية",
    "nauru–romania relations": "العلاقات الرومانية الناورونية",
    "nauru–russia relations": "العلاقات الروسية الناورونية",
    "nauru–switzerland relations": "العلاقات السويسرية الناورونية",
    "nauru–taiwan relations": "العلاقات التايوانية الناورونية",
    "nauru–united kingdom relations": "العلاقات البريطانية الناورونية",
    "nauru–united states relations": "العلاقات الأمريكية الناورونية",
    "nauru–venezuela relations": "العلاقات الفنزويلية الناورونية",
    "afghanistan–monaco relations": "العلاقات الأفغانية الموناكية",
    "albania–monaco relations": "العلاقات الألبانية الموناكية",
    "algeria–monaco relations": "العلاقات الجزائرية الموناكية",
    "andorra–monaco relations": "العلاقات الأندورية الموناكية",
    "angola–monaco relations": "العلاقات الأنغولية الموناكية",
    "argentina–monaco relations": "العلاقات الأرجنتينية الموناكية",
    "armenia–monaco relations": "العلاقات الأرمينية الموناكية",
    "australia–monaco relations": "العلاقات الأسترالية الموناكية",
    "austria–monaco relations": "العلاقات الموناكية النمساوية",
    "azerbaijan–monaco relations": "العلاقات الأذربيجانية الموناكية",
    "belarus–monaco relations": "العلاقات البيلاروسية الموناكية",
    "belgium–monaco relations": "العلاقات البلجيكية الموناكية",
    "bosnia and herzegovina–monaco relations": "العلاقات البوسنية الموناكية",
    "brazil–monaco relations": "العلاقات البرازيلية الموناكية",
    "brunei–monaco relations": "العلاقات البرونية الموناكية",
    "bulgaria–monaco relations": "العلاقات البلغارية الموناكية",
    "canada–monaco relations": "العلاقات الكندية الموناكية",
    "china–monaco relations": "العلاقات الصينية الموناكية",
    "colombia–monaco relations": "العلاقات الكولومبية الموناكية",
    "comoros–monaco relations": "العلاقات القمرية الموناكية",
    "czech republic–monaco relations": "العلاقات التشيكية الموناكية",
    "czechoslovakia–monaco relations": "العلاقات التشيكوسلوفاكية الموناكية",
    "denmark–monaco relations": "العلاقات الدنماركية الموناكية",
    "djibouti–monaco relations": "العلاقات الجيبوتية الموناكية",
    "egypt–monaco relations": "العلاقات المصرية الموناكية",
    "el salvador–monaco relations": "العلاقات السلفادورية الموناكية",
    "estonia–monaco relations": "العلاقات الإستونية الموناكية",
    "finland–monaco relations": "العلاقات الفنلندية الموناكية",
    "france–monaco relations": "العلاقات الفرنسية الموناكية",
    "gabon–monaco relations": "العلاقات الغابونية الموناكية",
    "germany–monaco relations": "العلاقات الألمانية الموناكية",
    "guinea–monaco relations": "العلاقات الغينية الموناكية",
    "iceland–monaco relations": "العلاقات الآيسلندية الموناكية",
    "india–monaco relations": "العلاقات الموناكية الهندية",
    "indonesia–monaco relations": "العلاقات الإندونيسية الموناكية",
    "ireland–monaco relations": "العلاقات الأيرلندية الموناكية",
    "israel–monaco relations": "العلاقات الإسرائيلية الموناكية",
    "ivory coast–monaco relations": "العلاقات الإيفوارية الموناكية",
    "jamaica–monaco relations": "العلاقات الجامايكية الموناكية",
    "japan–monaco relations": "العلاقات الموناكية اليابانية",
    "latvia–monaco relations": "العلاقات اللاتفية الموناكية",
    "lesotho–monaco relations": "العلاقات الليسوتية الموناكية",
    "luxembourg–monaco relations": "العلاقات اللوكسمبورغية الموناكية",
    "mexico–monaco relations": "العلاقات المكسيكية الموناكية",
    "monaco–montenegro relations": "العلاقات الموناكية المونتينيغرية",
    "monaco–netherlands relations": "العلاقات الموناكية الهولندية",
    "monaco–nigeria relations": "العلاقات الموناكية النيجيرية",
    "monaco–pakistan relations": "العلاقات الباكستانية الموناكية",
    "monaco–poland relations": "العلاقات البولندية الموناكية",
    "monaco–portugal relations": "العلاقات البرتغالية الموناكية",
    "monaco–qatar relations": "العلاقات القطرية الموناكية",
    "monaco–republic-of-congo relations": "العلاقات الكونغوية الموناكية",
    "monaco–romania relations": "العلاقات الرومانية الموناكية",
    "monaco–russia relations": "العلاقات الروسية الموناكية",
    "monaco–senegal relations": "العلاقات السنغالية الموناكية",
    "monaco–south korea relations": "العلاقات الكورية الجنوبية الموناكية",
    "monaco–spain relations": "العلاقات الإسبانية الموناكية",
    "monaco–sweden relations": "العلاقات السويدية الموناكية",
    "monaco–switzerland relations": "العلاقات السويسرية الموناكية",
    "monaco–syria relations": "العلاقات السورية الموناكية",
    "monaco–togo relations": "العلاقات التوغوية الموناكية",
    "monaco–ukraine relations": "العلاقات الأوكرانية الموناكية",
    "monaco–united kingdom relations": "العلاقات البريطانية الموناكية",
    "monaco–united states relations": "العلاقات الأمريكية الموناكية",
    "monaco–yugoslavia relations": "العلاقات الموناكية اليوغسلافية",
}

big_data2 = {
    "spanish american wars": "الحروب الأمريكية الإسبانية",
    "jewish roman wars": "الحروب الرومانية اليهودية",
    "jewish-roman wars": "الحروب الرومانية اليهودية",
    "Jewish-Roman wars": "الحروب الرومانية اليهودية",
    "cambodian–vietnamese war": "الحرب الفيتنامية الكمبودية",
    "chadian–libyan war": "الحرب التشادية الليبية",
    "dutch–portuguese war": "الحرب البرتغالية الهولندية",
    "ecuadorian–peruvian war": "الحرب الإكوادورية البيروية",
    "egyptian–ottoman war": "الحرب العثمانية المصرية",
    "eritrean–ethiopian war": "الحرب الإثيوبية الإريترية",
    "hungarian–czechoslovak war": "الحرب التشيكوسلوفاكية المجرية",
    "hungarian–romanian war": "الحرب الرومانية المجرية",
    "mexican–american war": "الحرب الأمريكية المكسيكية",
    "philippine–american war": "الحرب الأمريكية الفلبينية",
    "polish–lithuanian war": "الحرب البولندية الليتوانية",
    "polish–soviet war": "الحرب البولندية السوفيتية",
    "polish–ukrainian war": "الحرب الأوكرانية البولندية",
    "scottish–norwegian war": "الحرب الإسكتلندية النرويجية",
    "sinhalese–portuguese war": "الحرب البرتغالية السنهالية",
    "slovak–hungarian war": "الحرب السلوفاكية المجرية",
    "soviet–afghan war": "الحرب الأفغانية السوفيتية",
    "spanish–american war": "الحرب الأمريكية الإسبانية",
    "swedish–norwegian war": "الحرب السويدية النرويجية",
    "ukrainian–soviet war": "الحرب الأوكرانية السوفيتية",
    "algerian–tunisian wars": "الحروب التونسية الجزائرية",
    "arab–byzantine wars": "الحروب البيزنطية العربية",
    "bulgarian–ottoman wars": "الحروب البلغارية العثمانية",
    "bulgarian–serbian wars": "الحروب البلغارية الصربية",
    "byzantine–bulgarian wars": "الحروب البلغارية البيزنطية",
    "byzantine–georgian wars": "الحروب البيزنطية الجورجية",
    "byzantine–hungarian wars": "الحروب البيزنطية المجرية",
    "byzantine–ottoman wars": "الحروب البيزنطية العثمانية",
    "byzantine–sasanian wars": "الحروب البيزنطية الساسانية",
    "byzantine–turkish wars": "الحروب البيزنطية التركية",
    "ecuadorian–peruvian wars": "الحروب الإكوادورية البيروية",
    "hungarian–ottoman wars": "الحروب العثمانية المجرية",
    "jewish–roman wars": "الحروب الرومانية اليهودية",
    "ottoman–persian wars": "الحروب العثمانية الفارسية",
    "ottoman–serbian wars": "الحروب الصربية العثمانية",
    "polish–ottoman wars": "الحروب البولندية العثمانية",
    "polish–russian wars": "الحروب البولندية الروسية",
    "polish–ukrainian wars": "الحروب الأوكرانية البولندية",
    "roman–greek wars": "الحروب الرومانية اليونانية",
    "roman–parthian wars": "الحروب الرومانية الفرثية",
    "roman–persian wars": "الحروب الرومانية الفارسية",
    "roman–sasanian wars": "الحروب الرومانية الساسانية",
    "russian–ukrainian wars": "الحروب الأوكرانية الروسية",
    "japan–south vietnam relations": "علاقات اليابان وفيتنام الجنوبية",
    "philippines–south vietnam relations": "علاقات الفلبين وفيتنام الجنوبية",
    "south korea–south vietnam relations": "علاقات فيتنام الجنوبية وكوريا الجنوبية",
    "south vietnam–taiwan relations": "علاقات تايوان وفيتنام الجنوبية",
    "south vietnam–united states relations": "علاقات الولايات المتحدة وفيتنام الجنوبية",
    "somaliland–taiwan relations": "علاقات أرض الصومال وتايوان",
    "somaliland–united arab emirates relations": "علاقات أرض الصومال والإمارات العربية المتحدة",
    "somaliland–united kingdom relations": "علاقات أرض الصومال والمملكة المتحدة",
    "somaliland–united states relations": "علاقات أرض الصومال والولايات المتحدة",
    "djibouti–somaliland relations": "علاقات أرض الصومال وجيبوتي",
    "ethiopia–somaliland relations": "علاقات أرض الصومال وإثيوبيا",
    "germany–somaliland relations": "علاقات أرض الصومال وألمانيا",
    "israel–somaliland relations": "علاقات أرض الصومال وإسرائيل",
    "kosovo–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكوسوفو",
    "malta–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس ومالطا",
    "new zealand–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس ونيوزيلندا",
    "norway–saint kitts and nevis relations": "علاقات النرويج وسانت كيتس ونيفيس",
    "portugal–saint kitts and nevis relations": "علاقات البرتغال وسانت كيتس ونيفيس",
    "saint kitts and nevis–romania relations": "علاقات رومانيا وسانت كيتس ونيفيس",
    "saint kitts and nevis–spain relations": "علاقات إسبانيا وسانت كيتس ونيفيس",
    "australia–saint kitts and nevis relations": "علاقات أستراليا وسانت كيتس ونيفيس",
    "honduras–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وهندوراس",
    "iceland–saint kitts and nevis relations": "علاقات آيسلندا وسانت كيتس ونيفيس",
    "ireland–saint kitts and nevis relations": "علاقات أيرلندا وسانت كيتس ونيفيس",
    "saint kitts and nevis–thailand relations": "علاقات تايلاند وسانت كيتس ونيفيس",
    "saint kitts and nevis–united kingdom sports relations": "علاقات المملكة المتحدة وسانت كيتس ونيفيس الرياضية",
    "saint kitts and nevis–united states sports relations": "علاقات الولايات المتحدة وسانت كيتس ونيفيس الرياضية",
    "serbia and montenegro–slovakia relations": "علاقات سلوفاكيا وصربيا والجبل الأسود",
    "serbia and montenegro–yemen relations": "علاقات اليمن وصربيا والجبل الأسود",
    "kazakhstan–serbia and montenegro relations": "علاقات صربيا والجبل الأسود وكازاخستان",
    "russia–serbia and montenegro relations": "علاقات روسيا وصربيا والجبل الأسود",
    "czech republic–serbia and montenegro relations": "علاقات التشيك وصربيا والجبل الأسود",
    "austrian empire–kingdom of sardinia relations": "علاقات الإمبراطورية النمساوية ومملكة سردينيا",
    "dominica–mexico relations": "علاقات المكسيك ودومينيكا",
    "eswatini–poland relations": "علاقات إسواتيني وبولندا",
    "saint lucia–sri lanka relations": "علاقات سانت لوسيا وسريلانكا",
    "saint lucia–united kingdom sports relations": "علاقات المملكة المتحدة وسانت لوسيا الرياضية",
    "tokelau–united states relations": "علاقات الولايات المتحدة وتوكيلاو",
}

TEMPORAL_CASES = [
    ("test_same", test_same),
    ("test_big_data2", big_data2),
]


@pytest.mark.parametrize("category, expected", test_same.items(), ids=test_same.keys())
@pytest.mark.slow
def test_same(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", big_data2.items(), ids=big_data2.keys())
@pytest.mark.fast
def test_new_relations_resolvers_big_data(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: str) -> None:
    expected, diff_result = one_dump_test(data, new_relations_resolvers)

    dump_diff(diff_result, f"test_new_relations_resolvers_big_data_{name}")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



# test_convert_time_to_arabic.py
# -*- coding: utf-8 -*-
import pytest

from ArWikiCats.time_resolvers.time_to_arabic import match_en_return_ar

en_return_ar = {
    "Category:2020s in Yemen": {"2020s": "عقد 2020"},
    "events from 2010s to 2025": {"2010s": "عقد 2010", "2025": "2025"},
    "March 1917 events": {"March 1917": "مارس 1917"},
    "2020s in space": {"2020s": "عقد 2020"},
    "1990–91 in football": {"1990–91": "1990–91"},
    "events from 2020 to 2025": {"2020": "2020", "2025": "2025"},
    "2012-2013 in football": {"2012-2013": "2012-2013"},
    "2012-13 in football": {"2012-13": "2012-13"},
    "Category:10s": {"10s": "عقد 10"},
    "Category:10s BC": {"10s BC": "عقد 10 ق م"},
    "Category:10s BC births": {"10s BC": "عقد 10 ق م"},
    "Category:10s BC conflicts": {"10s BC": "عقد 10 ق م"},
    "Category:10s BC deaths": {"10s BC": "عقد 10 ق م"},
    "Category:Bridges completed in the 19th century": {"19th century": "القرن 19"},
    "Category:Bridges completed in the 1st century": {"1st century": "القرن 1"},
    "Category:Bridges completed in the 1st millennium": {"1st millennium": "الألفية 1"},
    "Category:Bridges completed in the 2000s": {"2000s": "عقد 2000"},
    "Category:Bridges completed in the 2010s": {"2010s": "عقد 2010"},
    "Category:Bridges completed in the 2020s": {"2020s": "عقد 2020"},
    "Category:Bridges completed in the 20th century": {"20th century": "القرن 20"},
    "Category:Bridges completed in the 21st century": {"21st century": "القرن 21"},
    "Category:Bridges completed in the 2nd century": {"2nd century": "القرن 2"},
    "Category:Bridges completed in the 2nd millennium": {"2nd millennium": "الألفية 2"},
    "Category:Bridges completed in the 7th century": {"7th century": "القرن 7"},
    "Category:Bridges completed in the 2nd millennium BC": {"2nd millennium BC": "الألفية 2 ق م"},
    "Category:Bridges completed in the 2nd century BC": {"2nd century BC": "القرن 2 ق م"},
    "Category:Bridges completed in the 1st century BC": {"1st century BC": "القرن 1 ق م"},
    "Category:Bridges completed in the 1st millennium BC": {"1st millennium BC": "الألفية 1 ق م"},
    "Category:Bridges completed in the 4th century BC": {"4th century BC": "القرن 4 ق م"},
    "Category:Bridges completed in the 4th-century BCE": {"4th-century BCE": "القرن 4 ق م"},
    "Category:7th-century BC disestablishments": {"7th-century BC": "القرن 7 ق م"},
    "Category:19th century-related lists": {"19th century": "القرن 19"},
    "Category:19th-century Afghan monarchs": {"19th-century": "القرن 19"},
    "Category:21st-century Afghan monarchs": {"21st-century": "القرن 21"},
    "Category:7th centuryBC Afghan monarchs": {"7th centuryBC": "القرن 7 ق م"},
    "Category:January events": {},
}


@pytest.mark.parametrize("en_text, expected", en_return_ar.items(), ids=en_return_ar.keys())
@pytest.mark.fast
def test_match_en_return_ar(en_text: str, expected: dict[str, str]) -> None:
    """Test various English time expressions for correct Arabic conversion."""
    result = match_en_return_ar(en_text)
    assert result == expected, f"{en_text} → {result}, {expected=}"



# -*- coding: utf-8 -*-
"""
TODO: add tests for the new suffixes added related to sports cups in: ArWikiCats.new.handle_suffixes
"""

import pytest

from ArWikiCats.new.handle_suffixes import combine_value_and_label, resolve_sport_category_suffix_with_mapping



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

entertainment_1 = {
    "Category:Action anime and manga": "تصنيف:أنمي ومانغا حركة",
    "Category:Action films by genre": "تصنيف:أفلام حركة حسب النوع الفني",
    "Category:Adventure anime and manga": "تصنيف:أنمي ومانغا مغامرات",
    "Category:Adventure films by genre": "تصنيف:أفلام مغامرات حسب النوع الفني",
    "Category:American Cinema Editors": "تصنيف:محررون سينمائون أمريكيون",
    "Category:American television episodes": "تصنيف:حلقات تلفزيونية أمريكية",
    "Category:American television series based on British television series": "تصنيف:مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية بريطانية",
    "Category:Apocalyptic anime and manga": "تصنيف:أنمي ومانغا نهاية العالم",
    "Category:Argentine songwriters": "تصنيف:كتاب أغان أرجنتينيون",
    "Category:Books about automobiles": "تصنيف:كتب عن سيارات",
    "Category:British editorial cartoonists": "تصنيف:محررون كارتونيون بريطانيون",
    "Category:British television chefs": "تصنيف:طباخو تلفاز بريطانيون",
    "Category:Cartoonists by publication": "تصنيف:رسامو كارتون حسب المؤسسة",
    # "Category:Characters in children's literature": "تصنيف:شخصيات في أدب الأطفال",
    "Category:Comedy anime and manga": "تصنيف:أنمي ومانغا كوميدية",
    "Category:Comedy films by genre": "تصنيف:أفلام كوميدية حسب النوع الفني",
    "Category:Comics adapted into films": "تصنيف:قصص مصورة تم تحويلها إلى أفلام",
    "Category:Comics based on films": "تصنيف:قصص مصورة مبنية على أفلام",
    "Category:Crime anime and manga": "تصنيف:أنمي ومانغا جريمة",
    "Category:Crime films by genre": "تصنيف:أفلام جريمة حسب النوع الفني",
    "Category:Dark fantasy video games": "تصنيف:ألعاب فيديو فانتازيا مظلمة",
    "Category:Dinosaurs in fiction": "تصنيف:ديناصورات في الخيال",
    "Category:Dinosaurs in video games": "تصنيف:ديناصورات في ألعاب فيديو",
    "Category:Disney animated films": "تصنيف:أفلام رسوم متحركة ديزني",
    "Category:Documentary films by genre": "تصنيف:أفلام وثائقية حسب النوع الفني",
}

entertainment_2 = {
    "Category:Drama anime and manga": "تصنيف:أنمي ومانغا درامية",
    "Category:Drama films by genre": "تصنيف:أفلام درامية حسب النوع الفني",
    "Category:Editorial cartoonists from Northern Ireland": "تصنيف:محررون كارتونيون من أيرلندا الشمالية",
    "Category:Erotic films by genre": "تصنيف:أفلام إغرائية حسب النوع الفني",
    "Category:Fantasy anime and manga": "تصنيف:أنمي ومانغا فانتازيا",
    "Category:Fantasy films by genre": "تصنيف:أفلام فانتازيا حسب النوع الفني",
    "Category:Fantasy video games": "تصنيف:ألعاب فيديو فانتازيا",
    "Category:Female comics writers": "تصنيف:كاتبات قصص مصورة",
    "Category:Figure skating films": "تصنيف:أفلام تزلج فني",
    "Category:Figure skating media": "تصنيف:إعلام تزلج فني",
    "Category:Films about Olympic boxing": "تصنيف:أفلام عن بوكسينغ أولمبي",
    "Category:Films about Olympic figure skating": "تصنيف:أفلام عن تزلج فني أولمبي",
    "Category:Films about Olympic gymnastics": "تصنيف:أفلام عن جمباز أولمبي",
    "Category:Films about Olympic skiing": "تصنيف:أفلام عن تزلج أولمبي",
    "Category:Films about Olympic track and field": "تصنيف:أفلام عن سباقات مضمار وميدان أولمبي",
    "Category:Films about automobiles": "تصنيف:أفلام عن سيارات",
    "Category:Films about the Olympic Games by athletic event": "تصنيف:أفلام عن الألعاب الأولمبية حسب حدث ألعاب القوى",
    "Category:Films based on American comics": "تصنيف:أفلام مبنية على قصص مصورة أمريكية",
    "Category:Films based on comics": "تصنيف:أفلام مبنية على قصص مصورة",
    "Category:Films based on television series": "تصنيف:أفلام مبنية على مسلسلات تلفزيونية",
    "Category:Films by audience": "تصنيف:أفلام حسب الجمهور",
    "Category:Films by continent": "تصنيف:أفلام حسب القارة",
    "Category:Films by culture": "تصنيف:أفلام حسب الثقافة",
    "Category:Films by date": "تصنيف:أفلام حسب التاريخ",
    "Category:Films by director": "تصنيف:أفلام حسب المخرج",
    "Category:Films by genre": "تصنيف:أفلام حسب النوع الفني",
    "Category:Films by language": "تصنيف:أفلام حسب اللغة",
    "Category:Films by movement": "تصنيف:أفلام حسب الحركة",
    "Category:Films by producer": "تصنيف:أفلام حسب المنتج",
    "Category:Films by setting location": "تصنيف:أفلام حسب موقع الأحداث",
    "Category:Films by shooting location": "تصنيف:أفلام حسب موقع التصوير",
    "Category:Films by source": "تصنيف:أفلام حسب المصدر",
    "Category:Films by studio": "تصنيف:أفلام حسب استوديو الإنتاج",
    "Category:Films by technology": "تصنيف:أفلام حسب التقانة",
    "Category:Films by topic": "تصنيف:أفلام حسب الموضوع",
    "Category:Films by type": "تصنيف:أفلام حسب الفئة",
    "Category:Films set in national parks": "تصنيف:أفلام تقع أحداثها في متنزهات وطنية",
    "Category:French comic strips": "تصنيف:شرائط كومكس فرنسية",
    "Category:Historical anime and manga": "تصنيف:أنمي ومانغا تاريخية",
    "Category:Historical comics": "تصنيف:قصص مصورة تاريخية",
    "Category:Historical fiction by setting location": "تصنيف:خيال تاريخي حسب موقع الأحداث",
    "Category:Historical television series": "تصنيف:مسلسلات تلفزيونية تاريخية",
    "Category:Horror anime and manga": "تصنيف:أنمي ومانغا رعب",
    "Category:Horror films by genre": "تصنيف:أفلام رعب حسب النوع الفني",
    "Category:LGBTQ-related films by genre": "تصنيف:أفلام متعلقة بإل جي بي تي كيو حسب النوع الفني",
    "Category:Lists of British television series characters by series": "تصنيف:قوائم شخصيات مسلسلات تلفزيونية بريطانية حسب السلسلة",
    "Category:Lists of television characters by series": "تصنيف:قوائم شخصيات تلفزيونية حسب السلسلة",
}

entertainment_3 = {
    "Category:Magical girl anime and manga": "تصنيف:أنمي ومانغا فتاة ساحرة",
    "Category:Mecha anime and manga": "تصنيف:أنمي ميكا",
    "Category:Musical films by genre": "تصنيف:أفلام موسيقية حسب النوع الفني",
    "Category:Mystery anime and manga": "تصنيف:أنمي ومانغا غموض",
    "Category:Mystery films by genre": "تصنيف:أفلام غموض حسب النوع الفني",
    "Category:Participants in British reality television series": "تصنيف:مشاركون في مسلسلات تلفزيونية واقعية بريطانية",
    "Category:Peruvian television actors": "تصنيف:ممثلو تلفزيون بيرويون",
    "Category:Philippine films by subgenre": "تصنيف:أفلام فلبينية حسب النوع الفرعي",
    "Category:Political films by genre": "تصنيف:أفلام سياسية حسب النوع الفني",
    "Category:Pornographic films by genre": "تصنيف:أفلام إباحية حسب النوع الفني",
    "Category:Romance anime and manga": "تصنيف:أنمي ومانغا رومانسية",
    "Category:Romance films by genre": "تصنيف:أفلام رومانسية حسب النوع الفني",
    "Category:Science fiction anime and manga": "تصنيف:أنمي ومانغا خيال علمي",
    "Category:Science fiction films by genre": "تصنيف:أفلام خيال علمي حسب النوع الفني",
    "Category:Songs about automobiles": "تصنيف:أغاني عن سيارات",
    "Category:South Korean television series by production location": "تصنيف:مسلسلات تلفزيونية كورية جنوبية حسب موقع الإنتاج",
    "Category:Sports anime and manga": "تصنيف:أنمي ومانغا رياضية",
    "Category:Sports films by genre": "تصنيف:أفلام رياضية حسب النوع الفني",
    "Category:Spy anime and manga": "تصنيف:أنمي ومانغا تجسسية",
    "Category:Spy films by genre": "تصنيف:أفلام تجسسية حسب النوع الفني",
    "Category:Supernatural anime and manga": "تصنيف:أنمي ومانغا خارقة للطبيعة",
    "Category:Teen films by genre": "تصنيف:أفلام مراهقة حسب النوع الفني",
    "Category:Television characters by series": "تصنيف:شخصيات تلفزيونية حسب السلسلة",
    "Category:Television programs by geographic setting": "تصنيف:برامج تلفزيونية حسب الموقع الجغرافي للأحداث",
    "Category:Television series produced in Alberta": "تصنيف:مسلسلات تلفزيونية أنتجت في ألبرتا",
    "Category:Television series produced in Seoul": "تصنيف:مسلسلات تلفزيونية أنتجت في سول",
    "Category:Television shows filmed in Algeria": "تصنيف:عروض تلفزيونية صورت في الجزائر",
    "Category:Thriller anime and manga": "تصنيف:أنمي ومانغا إثارة",
    "Category:Thriller films by genre": "تصنيف:أفلام إثارة حسب النوع الفني",
    "Category:Video games about diseases": "تصنيف:ألعاب فيديو عن الأمراض",
    "Category:Video games about slavery": "تصنيف:ألعاب فيديو عن العبودية",
    "Category:Video games based on Egyptian mythology": "تصنيف:ألعاب فيديو مبنية على أساطير مصرية",
    "Category:Video games based on mythology": "تصنيف:ألعاب فيديو مبنية على أساطير",
    "Category:Video games set in prehistory": "تصنيف:ألعاب فيديو تقع أحداثها في ما قبل التاريخ",
    "Category:Video games set in the Byzantine Empire": "تصنيف:ألعاب فيديو تقع أحداثها في الإمبراطورية البيزنطية",
    "Category:War anime and manga": "تصنيف:أنمي ومانغا حربية",
    "Category:War films by genre": "تصنيف:أفلام حربية حسب النوع الفني",
    "Category:Works about automobiles": "تصنيف:أعمال عن سيارات",
    "Category:Works adapted for other media": "تصنيف:أعمال تم تحويلها إلى وسائط أخرى",
    "Category:songs about busan": "تصنيف:أغاني عن بوسان",
}

ENTERTAINMENT_CASES = [
    ("entertainment_1", entertainment_1),
    ("entertainment_2", entertainment_2),
    ("entertainment_3", entertainment_3),
]


@pytest.mark.parametrize("category, expected", entertainment_1.items(), ids=entertainment_1.keys())
@pytest.mark.fast
def test_entertainment_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", entertainment_2.items(), ids=entertainment_2.keys())
@pytest.mark.fast
def test_entertainment_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", entertainment_3.items(), ids=entertainment_3.keys())
@pytest.mark.fast
def test_entertainment_3(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", ENTERTAINMENT_CASES)
@pytest.mark.dump
def test_entertainment(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


data2 = {
    "Category:documentary filmmakers by nationality": "تصنيف:صانعو أفلام وثائقية حسب الجنسية",
    "Category:yemeni war filmmakers": "تصنيف:صانعو أفلام حربية يمنيون",
    "Category:Peruvian documentary film directors": "تصنيف:مخرجو أفلام وثائقية بيرويون",
    "Category:Lists of action television characters by series": "تصنيف:قوائم شخصيات تلفزيونية حركة حسب السلسلة",
    "Category:Holocaust literature": "تصنيف:أدب هولوكوست",
    "Category:Drama television characters by series": "تصنيف:شخصيات تلفزيونية درامية حسب السلسلة",
    "Category:Fantasy television characters by series": "تصنيف:شخصيات تلفزيونية فانتازيا حسب السلسلة",
}


@pytest.mark.parametrize("input_text,expected", data2.items(), ids=data2.keys())
@pytest.mark.skip2("Need to fix")
def test_entertainment_5(input_text: str, expected: str) -> None:
    result = resolve_arabic_category_label(input_text)
    assert result == expected



import re

from ..helps import logger


def fix_minor(ar: str, ar_separator: str = "", en: str = "") -> str:
    """Clean up duplicate spaces and repeated prepositions in labels."""

    arlabel = " ".join(ar.strip().split())

    sps_list = [
        "من",
        "في",
        "و",
    ]

    ar_separator = ar_separator.strip()

    if ar_separator not in sps_list:
        sps_list.append(ar_separator)

    for ar_separator in sps_list:
        arlabel = re.sub(rf" {ar_separator}\s+{ar_separator} ", f" {ar_separator} ", arlabel)
        if ar_separator == "و":
            arlabel = re.sub(rf" {ar_separator} ", f" {ar_separator}", arlabel)

    arlabel = " ".join(arlabel.strip().split())

    logger.debug(f"fix_minor: {en=}| {ar=}  ==> {arlabel=}")

    return arlabel



#!/usr/bin/python3
"""
Module for time-based category translation formatting.

This module provides classes for handling year, decade, and century patterns
in category strings. It converts temporal expressions from English to Arabic
(e.g., "14th-century" → "القرن 14", "1990s" → "عقد 1990").

Classes:
    YearFormatDataLegacy: Legacy class for year pattern handling (deprecated).
    YearFormatData: Factory function that creates a FormatDataFrom instance for time patterns.

Example:
    >>> from ArWikiCats.translations_formats.DataModel import YearFormatData
    >>> year_bot = YearFormatData(key_placeholder="{year1}", value_placeholder="{year1}")
    >>> year_bot.search("14th-century")
    'القرن 14'
    >>> year_bot.search("1990s")
    'عقد 1990'

Note:
    The YearFormatData function is the preferred way to create year formatters.
    It returns a FormatDataFrom instance configured with the appropriate callbacks
    for time conversion.
"""

import re

from ...time_resolvers import (
    convert_time_to_arabic,
    fixing,
    match_time_en_first,
)
from ..formats_logger import logger
from .model_multi_data_year_from import FormatDataFrom


class YearFormatDataLegacy:
    """
    Legacy class for handling year patterns in category strings (deprecated).

    This class provides functionality to extract and convert year patterns
    (years, decades, centuries) from English to Arabic. It is kept for
    backward compatibility but the YearFormatData factory function should
    be used for new code.

    Attributes:
        key_placeholder (str): Placeholder string for the year key (e.g., "{year1}").
        value_placeholder (str): Placeholder string for the year value in templates.

    Example:
        >>> bot = YearFormatDataLegacy(key_placeholder="{year1}", value_placeholder="{year1}")
        >>> bot.match_key("14th-century writers")
        '14th-century'
        >>> bot.search("14th-century")
        'القرن 14'

    Note:
        Use YearFormatData() factory function instead of this class for new code.
    """

    def __init__(
        self,
        key_placeholder: str,
        value_placeholder: str,
    ) -> None:
        self.key_placeholder = key_placeholder
        self.value_placeholder = value_placeholder

    def match_key(self, text: str) -> str:
        """Extract English year/decade and return it as the key."""
        result = match_time_en_first(text)
        return result if result else ""

    def normalize_category(self, text: str, key: str) -> str:
        """
        Replace matched year with placeholder.
        """
        logger.debug(f"normalize_category: {key=}, {text=}")
        if not key:
            return text
        result = re.sub(re.escape(key), self.key_placeholder, text, flags=re.IGNORECASE)
        return result

    def normalize_category_with_key(self, category: str) -> tuple[str, str]:
        """
        Normalize nationality placeholders within a category string.

        Example:
            category:"Yemeni national football teams", result: "natar national football teams"
        """
        key = self.match_key(category)
        result = ""
        if key:
            result = self.normalize_category(category, key)
        return key, result

    def replace_value_placeholder(self, label: str, value: str) -> str:
        # Replace placeholder
        logger.debug(f"!!!! replace_value_placeholder: {self.value_placeholder=}, {label=}, {value=}")
        result = label.replace(self.value_placeholder, value)
        result = fixing(result)
        return result

    def get_key_label(self, key: str) -> str:
        """place holders"""
        if not key:
            return ""
        logger.debug(f"get_key_label: {key=}")
        return self.search(key)

    def search(self, text: str) -> str:
        """Convert the year expression to Arabic."""
        return convert_time_to_arabic(text)

    def search_all(self, key: str) -> str:
        """place holders"""
        return self.search(key)


def YearFormatData(
    key_placeholder: str,
    value_placeholder: str,
) -> FormatDataFrom:
    """
    Factory function to create a FormatDataFrom instance for year/time patterns.

    This is the preferred way to create year formatters. It returns a FormatDataFrom
    instance configured with the appropriate callbacks for converting English
    temporal expressions to Arabic.

    Args:
        key_placeholder: Placeholder string for the year key (e.g., "{year1}").
        value_placeholder: Placeholder string for the year value in templates.

    Returns:
        FormatDataFrom: A configured formatter for handling year patterns.

    Example:
        >>> year_bot = YearFormatData(key_placeholder="{year1}", value_placeholder="{year1}")
        >>> year_bot.search("14th-century")
        'القرن 14'
        >>> year_bot.match_key("14th-century writers from Yemen")
        '14th-century'
    """
    return FormatDataFrom(
        formatted_data={},
        key_placeholder=key_placeholder,
        value_placeholder=value_placeholder,
        search_callback=convert_time_to_arabic,
        match_key_callback=match_time_en_first,
        fixing_callback=fixing,
    )



import functools

from ...helps import logger
from . import (
    resolve_v3i,
    resolve_v3ii,
)


@functools.lru_cache(maxsize=None)
def resolve_v3i_main(normalized_category) -> str:
    normalized_category = normalized_category.strip().lower().replace("category:", "")
    logger.debug("--" * 20)
    logger.debug(f"<><><><><><> <<green>> Trying v3i resolvers for: {normalized_category=}")

    resolved_label = (
        resolve_v3i.resolve_year_job_from_countries(normalized_category)
        or resolve_v3ii.resolve_year_job_countries(normalized_category)
        or ""
    )

    logger.info_if_or_debug(
        f"<<yellow>> end resolve_v3i_main: {normalized_category=}, {resolved_label=}", resolved_label
    )
    return resolved_label


__all__ = [
    "resolve_v3i_main",
]



"""
# TODO: ADD SOME DATA FROM D:/categories_bot/langlinks/z2_data/YEAR.json"""

YEAR_PARAM_NAME = "year1"

YEAR_DATA = {
    "{year1} establishments": "تأسيسات سنة {year1}",  # 1243
    "{year1}s disestablishments": "انحلالات عقد {year1}",  # 699
    "{year1} disestablishments": "انحلالات سنة {year1}",  # 699
    "{year1} disestablishments by continent": "انحلالات سنة {year1} حسب القارة",  # 368
    "{year1} disestablishments by country": "انحلالات سنة {year1} حسب البلد",  # 347
    "{year1} establishments by continent": "تأسيسات سنة {year1} حسب القارة",  # 523
    "{year1} establishments by country": "تأسيسات سنة {year1} حسب البلد",  # 731
    "{year1} establishments in ottoman empire": "تأسيسات سنة {year1} في الدولة العثمانية",  # 211
    "{year1} establishments in russian empire": "تأسيسات سنة {year1} في الإمبراطورية الروسية",  # 152
    "{year1} establishments in spanish empire": "تأسيسات سنة {year1} في الإمبراطورية الإسبانية",  # 256
    "{year1} elections": "انتخابات {year1}",  # 214
    # "{year1} elections": "انتخابات في {year1}",  # 214
    "{year1} novels": "روايات {year1}",  # 317
    "{year1} sports-events": "أحداث {year1} الرياضية",
    "{year1} sports events": "أحداث {year1} الرياضية",  # 1295
    "{year1} censuses": "تعداد السكان في {year1}",
    "{year1} science fiction works": "أعمال خيال علمي {year1}",
    "{year1} controversies": "خلافات {year1}",
    "{year1} floods": "فيضانات {year1}",
    "{year1} mass shootings": "إطلاق نار عشوائي {year1}",
    "{year1} murders": "جرائم قتل في {year1}",
    # "{year1} murders": "قتل في {year1}",  # 300
    "{year1} music": "الموسيقى في {year1}",
    "{year1} theatre": "المسرح في {year1}",
    "{year1} cookbooks": "كتب طبخ {year1}",
    "{year1} musicals": "مسرحيات غنائية {year1}",
    "{year1} racehorse deaths": "خيول سباق نفقت في {year1}",
    "{year1} mining disasters": "كوارث التعدين {year1}",
    "{year1} albums": "ألبومات {year1}",
    "{year1} Christmas albums": "ألبومات عيد الميلاد {year1}",
    "{year1} landslides": "انهيارات أرضية {year1}",
    "{year1} publications": "منشورات {year1}",
    "{year1} revolutions": "ثورات {year1}",
    "{year1} transport disasters": "كوارث نقل في {year1}",
    "{year1} mosques": "مساجد {year1}",
    "{year1} texts": "نصوص {year1}",
    "{year1} executions": "إعدامات في {year1}",
    "{year1} buddhist temples": "معابد بوذية {year1}",
    "{year1} jain temples": "معابد جاينية {year1}",
    "{year1} hindu temples": "معابد هندوسية {year1}",
    "{year1} literature": "أدب {year1}",
    "{year1} essays": "مقالات {year1}",
    "{year1} operas": "أوبيرات {year1}",
    "{year1} missing person cases": "قضايا أشخاص مفقودين في {year1}",
    "{year1} meteorology": "الأرصاد الجوية في {year1}",
    "refugee olympic team in {year1} summer olympics": "فريق الرياضيين الأولمبيين اللاجئين في الألعاب الأولمبية الصيفية {year1}",
    "refugee olympic team in {year1} winter olympics": "فريق الرياضيين الأولمبيين اللاجئين في الألعاب الأولمبية الشتوية {year1}",
    "{year1} television series-debuts": "مسلسلات تلفزيونية بدأ عرضها في {year1}",
    "{year1} television series debuts": "مسلسلات تلفزيونية بدأ عرضها في {year1}",
    "{year1} in mass media": "وسائل الإعلام في {year1}",  # 126
    "airlines established in {year1}": "شركات طيران أسست في {year1}",  # 259
    "animals described in {year1}": "حيوانات وصفت في {year1}",  # 266
    "articles containing potentially dated statements from {year1}": "مقالات فيها عبارات متقادمة منذ {year1}",  # 183
    "articles lacking reliable references from {year1}": "مقالات ينقصها مصادر موثوق بها منذ {year1}",  # 181
    "articles lacking sources from {year1}": "مقالات بدون مصدر منذ {year1}",  # 178
    "articles with dead external links from {year1}": "مقالات ذات وصلات خارجية مكسورة منذ {year1}",  # 171
    "articles with unsourced statements from {year1}": "مقالات ذات عبارات بحاجة لمصادر منذ {year1}",  # 212
    "association football clubs established in {year1}": "أندية كرة قدم أسست في {year1}",  # 167
    "astronomical objects discovered in {year1}": "أجرام فلكية اكتشفت في {year1}",  # 242
    "awards established in {year1}": "جوائز أسست في {year1}",  # 190
    "birds described in {year1}": "طيور وصفت في {year1}",  # 225
    "buildings and structures completed in {year1}": "مبان ومنشآت اكتملت في {year1}",  # 791
    "churches completed in {year1}": "كنائس اكتملت في {year1}",  # 247
    "clean-up categories from {year1}": "تصنيفات تهذيب منذ {year1}",  # 188
    "companies established in {year1} by country": "شركات أسست في {year1} حسب البلد",  # 235
    "companies established in {year1}": "شركات أسست في {year1}",  # 282
    "conflicts in {year1}": "نزاعات في {year1}",  # 817
    "educational institutions established in {year1}": "هيئات تعليمية أسست في {year1}",  # 266
    "educational organizations established in {year1}": "منظمات تعليمية أسست في {year1}",  # 276
    "event venues established in {year1}": "صالات أحداث أسست في {year1}",  # 170
    "fiction set in {year1}": "أعمال خيالية في {year1}",  # 206
    "films set in {year1}": "أفلام تقع أحداثها في {year1}",  # 283
    "fish described in {year1}": "أسماك وصفت في {year1}",  # 222
    "fossil taxa described in {year1}": "أصنوفات أحفورية وصفت في {year1}",  # 201
    "fungi described in {year1}": "فطريات وصفت في {year1}",  # 206
    "government agencies established in {year1}": "وكالات حكومية أسست في {year1}",  # 165
    "houses completed in {year1}": "منازل اكتملت في {year1}",  # 213
    "infrastructure completed in {year1}": "بنية تحتية اكتملت في {year1}",  # 268
    "insects described in {year1}": "حشرات وصفت في {year1}",  # 199
    "mammals described in {year1}": "ثدييات وصفت في {year1}",  # 247
    "manufacturing companies established in {year1}": "شركات تصنيع أسست في {year1}",  # 194
    "maritime incidents in {year1}": "حوادث بحرية في {year1}",  # 256
    "mass murder in {year1}": "قتل جماعي في {year1}",  # 172
    "military units and formations established in {year1}": "وحدات وتشكيلات عسكرية أسست في {year1}",  # 196
    "mosques completed in {year1}": "مساجد اكتملت في {year1}",  # 243
    "murder in {year1}": "قتل في {year1}",  # 241
    "museums established in {year1}": "متاحف أسست في {year1}",  # 129
    "organizations disestablished in {year1}": "منظمات انحلت في {year1}",  # 170
    "organizations established in {year1}": "منظمات أسست في {year1}",  # 259
    "people murdered in {year1}": "أشخاص قتلوا في {year1}",  # 210
    "plants described in {year1}": "نباتات وصفت في {year1}",  # 260
    "political parties established in {year1}": "أحزاب سياسية أسست في {year1}",  # 168
    "populated places established in {year1}": "أماكن مأهولة أسست في {year1}",  # 521
    "publications established in {year1}": "منشورات أسست في {year1}",  # 217
    "railway stations opened in {year1}": "محطات السكك الحديدية افتتحت في {year1}",  # 169
    "religious organizations established in {year1}": "منظمات دينية أسست في {year1}",  # 169
    "reptiles described in {year1}": "زواحف وصفت في {year1}",  # 192
    "residential buildings completed in {year1}": "مبان سكنية اكتملت في {year1}",  # 182
    "species described in {year1}": "أنواع وصفت في {year1}",  # 271
    "sports clubs and teams established in {year1}": "أندية وفرق رياضية أسست في {year1}",  # 152
    "sports organizations established in {year1}": "منظمات رياضية أسست في {year1}",  # 170
    "states and territories disestablished in {year1}": "دول وأقاليم انحلت في {year1}",  # 174
    "states and territories established in {year1}": "دول وأقاليم أسست في {year1}",  # 224
    "taxa described in {year1}": "أصنوفات وصفت في {year1}",  # 270
    "transport companies established in {year1}": "شركات نقل أسست في {year1}",
    "transport disasters in {year1}": "كوارث نقل في {year1}",  # 149
    "transport infrastructure completed in {year1}": "بنية تحتية للنقل اكتملت في {year1}",  # 233
    "universities and colleges established in {year1}": "جامعات وكليات أسست في {year1}",  # 189
    "{year1} architecture": "عمارة {year1}",  # 215
    "{year1} bc deaths": "وفيات {year1} ق م",  # 440
    "{year1} bc": "{year1} ق م",  # 649
    "{year1} beginnings": "بدايات {year1}",  # 1946
    "{year1} attacks": "هجمات {year1}",
    "{year1} births": "مواليد {year1}",  # 1923
    "{year1} books": "كتب {year1}",  # 581
    "{year1} by city": "{year1} حسب المدينة",  # 233
    "{year1} by continent": "{year1} حسب القارة",  # 1098
    "{year1} by country": "{year1} حسب البلد",  # 1111
    "{year1} by month": "أحداث {year1} حسب الشهر",  # 225
    "{year1} conflicts": "نزاعات في {year1}",  # 215
    "{year1} crimes by continent": "جرائم {year1} حسب القارة",  # 285
    "{year1} crimes by country": "جرائم {year1} حسب البلد",  # 224
    "{year1} crimes": "جرائم {year1}",  # 601
    "{year1} deaths": "وفيات {year1}",  # 2045
    "{year1} disasters by country": "كوارث في {year1} حسب البلد",  # 86
    "{year1} disasters": "كوارث {year1}",  # 322
    "{year1} documents": "وثائق في {year1}",  # 179
    "{year1} domestic association football cups": "كؤوس كرة قدم محلية {year1}",  # 288
    "{year1} domestic association football leagues": "دوريات كرة قدم محلية {year1}",  # 142
    "{year1} earthquakes": "زلازل {year1}",  # 171
    "{year1} elections by country": "انتخابات {year1} حسب البلد",  # 189
    "{year1} endings": "نهايات {year1}",  # 1970
    "{year1} events by continent": "أحداث {year1} حسب القارة",  # 967
    "{year1} events by country": "أحداث {year1} حسب البلد",  # 956
    "{year1} events by month": "أحداث {year1} حسب الشهر",  # 228
    "{year1} events": "أحداث {year1}",  # 2020
    "{year1} in art": "الفن في {year1}",  # 449
    "{year1} in association football by continent": "كرة القدم في {year1} حسب القارة",  # 180
    "{year1} in association football": "كرة القدم في {year1}",  # 350
    "{year1} in biology": "علم الأحياء في {year1}",  # 180
    "{year1} in christianity": "المسيحية في {year1}",  # 369
    "{year1} in domestic association football": "كرة قدم محلية في {year1}",  # 285
    # "{year1} in economic history": "الاقتصاد في {year1}",  # 251
    "{year1} in economics": "{year1} في الاقتصاد",  # 287
    "{year1} in education": "التعليم في {year1}",  # 258
    "{year1} in english sport": "رياضة إنجليزية في {year1}",  # 164
    "{year1} in film": "{year1} في الأفلام",  # 140
    "{year1} in football": "{year1} في كرة القدم",  # 163
    "{year1} in health": "الصحة في {year1}",  # 194
    "{year1} in international relations": "علاقات دولية في {year1}",  # 468
    "{year1} in law": "القانون في {year1}",  # 477
    "{year1} in literature": "الأدب في {year1}",  # 474
    "{year1} in military history": "التاريخ العسكري في {year1}",  # 570
    "{year1} in music": "موسيقى في {year1}",  # 169
    "{year1} in paleontology": "علم الأحياء القديمة في {year1}",  # 215
    "{year1} in politics": "السياسة في {year1}",  # 552
    "{year1} in rail transport": "السكك الحديدية في {year1}",  # 182
    "{year1} in religion": "الدين في {year1}",  # 592
    "{year1} in science": "العلم في {year1}",  # 540
    "{year1} in sport by continent": "رياضة في {year1} حسب القارة",  # 181
    "{year1} in sports by country": "ألعاب رياضية في {year1} حسب البلد",  # 190
    "{year1} in sports": "ألعاب رياضية في {year1}",  # 1295
    "{year1} in technology": "التقانة في {year1}",  # 164
    "{year1} in tennis": "كرة المضرب في {year1}",  # 164
    "{year1} in arts": "الفنون في {year1}",  # 734
    "{year1} in environment": "البيئة في {year1}",  # 283
    "{year1} in ottoman empire": "الدولة العثمانية في {year1}",  # 349
    "{year1} in russian empire": "الإمبراطورية الروسية في {year1}",  # 192
    "{year1} in spanish empire": "الإمبراطورية الإسبانية في {year1}",  # 315
    "{year1} in theatre": "المسرح في {year1}",  # 262
    "{year1} in transport": "النقل في {year1}",  # 279
    "{year1} introductions": "استحداثات {year1}",  # 275
    "{year1} murders by continent": "جرائم قتل في {year1} حسب القارة",  # 157
    "{year1} murders by country": "جرائم قتل في {year1} حسب البلد",  # 187
    "{year1} natural disasters": "كوارث طبيعية في {year1}",  # 132
    "{year1} non fiction books": "كتب غير خيالية {year1}",  # 312
    "{year1} non-fiction books": "كتب غير خيالية {year1}",  # 312
    "{year1} paintings": "لوحات {year1}",  # 346
    "{year1} plays": "مسرحيات {year1}",  # 257
    "{year1} poems": "قصائد {year1}",  # 180
    "{year1} sculptures": "منحوتات {year1}",  # 179
    "{year1} ships": "سفن {year1}",  # 200
    "{year1} short stories": "قصص قصيرة {year1}",  # 177
    "{year1} songs": "أغاني {year1}",  # 172
    "{year1} treaties": "معاهدات في {year1}",  # 283
    "{year1} works": "أعمال في {year1}",  # 945
    "{year1}": "{year1}",  # 2387
}



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_with_sports.p17_sport_to_move_under import resolve_sport_under_labels

# =========================================================
#
# =========================================================

data_no_nats = {
    "softball national youth womens under-24 teams": "منتخبات كرة لينة تحت 24 سنة للشابات",
    "national mens under-19 softball teams": "منتخبات كرة لينة تحت 19 سنة للرجال",
    "multi-national womens under-19 football teams": "منتخبات كرة قدم تحت 19 سنة متعددة الجنسيات للسيدات",
}

data_with_nats = {
    "egypt under-19 international players": "لاعبون تحت 19 سنة دوليون من مصر",
    "aruba men's under-20 international footballers": "لاعبو منتخب أروبا تحت 20 سنة لكرة القدم للرجال",
    "egypt amateur under-19 international footballers": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للهواة",
    "egypt amateur under-19 international soccer players": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للهواة",
    "egypt amateur under-20 international footballers": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للهواة",
    "egypt amateur under-20 international soccer players": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للهواة",
    "egypt men's a' under-19 international footballers": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للرجال للمحليين",
    "egypt men's a' under-19 international soccer players": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للرجال للمحليين",
    "egypt men's a' under-20 international footballers": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للرجال للمحليين",
    "egypt men's a' under-20 international soccer players": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للرجال للمحليين",
    "egypt men's b under-19 international footballers": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم الرديف للرجال",
    "egypt men's b under-19 international soccer players": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم الرديف للرجال",
    "egypt men's b under-20 international footballers": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم الرديف للرجال",
    "egypt men's b under-20 international soccer players": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم الرديف للرجال",
    "egypt men's under-19 international footballers": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للرجال",
    "egypt men's under-19 international soccer players": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للرجال",
    "egypt men's under-20 international footballers": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للرجال",
    "egypt men's under-20 international soccer players": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للرجال",
    "egypt men's youth under-19 international footballers": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للشباب",
    "egypt men's youth under-19 international soccer players": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للشباب",
    "egypt men's youth under-20 international footballers": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للشباب",
    "egypt men's youth under-20 international soccer players": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للشباب",
    "egypt under-19 international footballers": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم",
    "egypt under-19 international managers": "مدربون تحت 19 سنة دوليون من مصر",
    "egypt under-19 international soccer players": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم",
    "egypt under-20 international footballers": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم",
    "egypt under-20 international managers": "مدربون تحت 20 سنة دوليون من مصر",
    "egypt under-20 international soccer players": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم",
    "egypt women's under-19 international footballers": "لاعبات منتخب مصر تحت 19 سنة لكرة القدم للسيدات",
    "egypt women's under-19 international soccer players": "لاعبات منتخب مصر تحت 19 سنة لكرة القدم للسيدات",
    "egypt women's under-20 international footballers": "لاعبات منتخب مصر تحت 20 سنة لكرة القدم للسيدات",
    "egypt women's under-20 international soccer players": "لاعبات منتخب مصر تحت 20 سنة لكرة القدم للسيدات",
    "egypt women's youth under-19 international footballers": "لاعبات منتخب مصر تحت 19 سنة لكرة القدم للشابات",
    "egypt women's youth under-19 international soccer players": "لاعبات منتخب مصر تحت 19 سنة لكرة القدم للشابات",
    "egypt women's youth under-20 international footballers": "لاعبات منتخب مصر تحت 20 سنة لكرة القدم للشابات",
    "egypt women's youth under-20 international soccer players": "لاعبات منتخب مصر تحت 20 سنة لكرة القدم للشابات",
    "egypt youth under-19 international footballers": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للشباب",
    "egypt youth under-19 international soccer players": "لاعبو منتخب مصر تحت 19 سنة لكرة القدم للشباب",
    "egypt youth under-20 international footballers": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للشباب",
    "egypt youth under-20 international soccer players": "لاعبو منتخب مصر تحت 20 سنة لكرة القدم للشباب",
    "lithuania men's under-21 international footballers": "لاعبو منتخب ليتوانيا تحت 21 سنة لكرة القدم للرجال",
    "mauritania men's under-20 international footballers": "لاعبو منتخب موريتانيا تحت 20 سنة لكرة القدم للرجال",
    "yemen under-13 international footballers": "لاعبو منتخب اليمن تحت 13 سنة لكرة القدم",
    "yemen under-14 international footballers": "لاعبو منتخب اليمن تحت 14 سنة لكرة القدم",
}


@pytest.mark.parametrize("category, expected", data_no_nats.items(), ids=data_no_nats.keys())
@pytest.mark.fast
def test_data_no_nats(category: str, expected: str) -> None:
    label2 = resolve_sport_under_labels(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", data_with_nats.items(), ids=data_with_nats.keys())
@pytest.mark.fast
def test_data_with_nats(category: str, expected: str) -> None:
    label2 = resolve_sport_under_labels(category)
    assert label2 == expected


# =========================================================
#           DUMP
# =========================================================


TEMPORAL_CASES = [
    ("test_data_no_nats", data_no_nats, resolve_sport_under_labels),
    ("test_data_with_nats", data_with_nats, resolve_sport_under_labels),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback, do_strip=False)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

import pytest

from ArWikiCats.new.end_start_bots.fax2_temp import get_templates_fo


@pytest.mark.fast
def test_get_templates_fo() -> None:
    # Test with a templates category
    list_of_cat, category3 = get_templates_fo("test templates")
    assert isinstance(list_of_cat, str)
    assert isinstance(category3, str)

    # Test with empty string
    list_of_cat_empty, category3_empty = get_templates_fo("")
    assert isinstance(list_of_cat_empty, str)
    assert isinstance(category3_empty, str)


@pytest.mark.fast
def test_specific_keys_in_dict_temps() -> None:
    # Test each specific known key branch
    cases = {
        "squad templates": "قوالب تشكيلات {}",
    }

    for key, expected_lab in cases.items():
        inp = f"MyCategory {key}"
        list_of_cat, category3 = get_templates_fo(inp)

        assert list_of_cat == expected_lab
        assert category3 == "MyCategory"  # key removed
        assert not category3.endswith("templates")


@pytest.mark.fast
def test_generic_templates_fallback() -> None:
    # Should use: list_of_cat = "قوالب {}"
    list_of_cat, category3 = get_templates_fo("ExampleCategory templates")

    assert list_of_cat == "قوالب {}"
    assert category3 == "ExampleCategory"


@pytest.mark.fast
def test_no_templates_anywhere_returns_original() -> None:
    # If no match and doesn't end with "templates", category remains as-is
    list_of_cat, category3 = get_templates_fo("RandomCategory")

    assert list_of_cat == ""
    assert category3 == "RandomCategory"


@pytest.mark.fast
def test_empty_string() -> None:
    list_of_cat, category3 = get_templates_fo("")

    assert list_of_cat == ""
    assert category3 == ""


@pytest.mark.fast
def test_spaces_are_stripped_correctly() -> None:
    list_of_cat, category3 = get_templates_fo("  myname   templates   ")

    assert list_of_cat == "قوالب {}"
    assert category3 == "myname"


@pytest.mark.fast
def test_no_key_but_word_templates_inside_not_at_end() -> None:
    # Should NOT remove "templates" in the middle
    # لأنه لا ينتهي بـ " templates"
    list_of_cat, category3 = get_templates_fo("my templates category")

    # default fallback will fire because it does NOT end with " templates"
    assert list_of_cat == ""
    assert category3 == "my templates category"
